@@ -29,7 +29,7 @@ namespace KDevelop {
 
 
 IDebugSession::IDebugSession()
-    : m_job(0), m_breakpointController(0)
+    : m_breakpointController(0)
 {
 }
 
@@ -37,11 +37,6 @@ IDebugSession::~IDebugSession()
 {
 }
 
-KJob *IDebugSession::job() const
-{
-    return m_job;
-}
-
 bool IDebugSession::isRunning() const
 {
     DebuggerState s = state();
