@@ -25,6 +25,8 @@
 
 namespace KDevelop {
 
+static bool onDiskChangesForbidden = false;
+
 class EditorCodeRepresentation : public DynamicCodeRepresentation {
   public:
   EditorCodeRepresentation(KTextEditor::Document* document) : m_document(document) {
@@ -100,6 +102,7 @@ class FileCodeRepresentation : public CodeRepresentation {
     }
     
     bool setText(QString text) {
+      Q_ASSERT(!onDiskChangesForbidden);
       QString localFile(m_document.toUrl().toLocalFile());
 
       QFile file( localFile );
@@ -118,12 +121,91 @@ class FileCodeRepresentation : public CodeRepresentation {
     QByteArray data;
 };
 
+class ArtificialStringData : public QSharedData {
+    public:
+    ArtificialStringData(QString data) {
+        setData(data);
+    }
+    void setData(QString data) {
+        m_data = data;
+        m_lineData = m_data.split('\n');
+    }
+    QString data() const {
+        return m_data;
+    }
+    QStringList lines() const {
+        return m_lineData;
+    }
+    private:
+    QString m_data;
+    QStringList m_lineData;
+};
+
+class StringCodeRepresentation : public CodeRepresentation {
+  public:
+    StringCodeRepresentation(KSharedPtr<ArtificialStringData> _data) : data(_data) {
+    }
+    
+    QString line(int line) const {
+    if(line < 0 || line >= data->lines().size())
+      return QString();
+      
+      return data->lines()[line];
+    }
+    
+    virtual int lines() const {
+        return data->lines().count();
+    }
+    
+    QString text() const {
+        return data->data();
+    }
+    
+    bool setText(QString text) {
+        data->setData(text);
+        return true;
+    }
+    
+  private:
+    KSharedPtr<ArtificialStringData> data;
+};
+
+static QHash<IndexedString, KSharedPtr<ArtificialStringData> > artificialStrings;
+
 CodeRepresentation* createCodeRepresentation(IndexedString url) {
+    if(artificialStrings.contains(url))
+        return new StringCodeRepresentation(artificialStrings[url]);
+    
   IDocument* document = ICore::self()->documentController()->documentForUrl(url.toUrl());
   if(document && document->textDocument())
     return new EditorCodeRepresentation(document->textDocument());
   else
     return new FileCodeRepresentation(url);
 }
+
+void CodeRepresentation::setDiskChangesForbidden(bool changesForbidden)
+{
+    onDiskChangesForbidden = changesForbidden;
+}
+
+InsertArtificialCodeRepresentation::InsertArtificialCodeRepresentation(IndexedString file, QString text) : m_file(file) {
+    artificialStrings.insert(file, KSharedPtr<ArtificialStringData>(new ArtificialStringData(text)));
+}
+
+InsertArtificialCodeRepresentation::~InsertArtificialCodeRepresentation() {
+    Q_ASSERT(artificialStrings.contains(m_file));
+    artificialStrings.remove(m_file);
+}
+
+void InsertArtificialCodeRepresentation::setText(QString text) {
+    Q_ASSERT(artificialStrings.contains(m_file));
+    artificialStrings[m_file]->setData(text);
+}
+
+QString InsertArtificialCodeRepresentation::text() {
+    Q_ASSERT(artificialStrings.contains(m_file));
+    return artificialStrings[m_file]->data();
+}
+
 }
 
