@@ -19,16 +19,21 @@
 #ifndef DUCHAINCHANGESET_H
 #define DUCHAINCHANGESET_H
 
-#include <QVariant>
+#include <QtCore/QVariant>
 
 #include "../duchain/identifier.h"
 #include "../duchain/topducontext.h"
+#include "../duchain/declaration.h"
 
 namespace KDevelop {
 
 class DUChainChangeSet;
 class DUChainChange;
 class DUChainBase;
+class DUContextRef;
+
+template <typename AstNode>
+class AstNodeRef;
 
 /**
  * \short A reference to an existing read-only DUChain object.
@@ -43,12 +48,12 @@ class DUChainBase;
  */
 class KDEVPLATFORMLANGUAGE_EXPORT DUChainRef
 {
-    friend class DUChainChangeSet;
+/*    friend class DUChainChangeSet;
 
 public:
     virtual ~DUChainRef();
 
-    virtual const DUChainBase* object() const;
+    virtual const DUChainBase* object() const = 0;
     virtual const DUContext* context() const;
     virtual const Declaration* declaration() const;
 
@@ -85,7 +90,8 @@ public:
      *          exists (after any existing duchain changes are applied).  Changes
      *          made to the AST will be applied along with the duchain change set.
      */
-    AstNodeRef* rewriteAst();
+/*    template <typename AstNode>
+    AstNodeRef<AstNode> * rewriteAst();
 
     /// Removes a change from this object reference, and deletes it.
     void deleteChange(DUChainChange* change);
@@ -105,7 +111,7 @@ private:
     DUChainRef* m_objectRef;
     bool m_newObject;
 
-    QList<DUChainChange*> m_changes;
+    QList<DUChainChange*> m_changes;*/
 };
 
 typedef QList<DUChainRef*> DUChainBaseList;
@@ -118,8 +124,6 @@ typedef QList<DUChainRef*> DUChainBaseList;
 class KDEVPLATFORMLANGUAGE_EXPORT DUChainChange
 {
 public:
-    DUChainChange(ChangeTypes t);
-
     enum ChangeTypes {
         Rename,
         ListInsert,
@@ -130,6 +134,8 @@ public:
         TypeChange
     } type;
 
+    DUChainChange(ChangeTypes t) : type(t) {}
+
     enum ItemToChange {
         ContextChildren,
         ContextDeclarations
@@ -138,13 +144,13 @@ public:
     /// New local identifier (eg. for contexts, the new DUContext::localScopeIdentifier() )
     QualifiedIdentifier newIdentifier;
 
-    // The new object to occupy this position, if relevant
+    /// The new object to occupy this position, if relevant
     DUChainRef* newObject;
-    // The list of objects to occupy this position, if relevant
+    /// The list of objects to occupy this position, if relevant
     DUChainBaseList newList;
-    // The position to apply the object(s) in the list, if relevant
+    /// The position to apply the object(s) in the list, if relevant
     int listOffset;
-    // The value of the position, if relevant
+    /// The value of the position, if relevant
     QVariant newValue;
 
     AbstractType::Ptr newType;
@@ -204,6 +210,15 @@ public:
      * \returns the new object reference
      */
     DUChainRef* copyRef(DUChainRef* ref);
+    
+    /**
+     * Merge another changeset with this one. This changeset
+     * takes ownership of all the objects in the other changeset.
+     * After the merge, the merged object becomes empty.
+     *
+     * Both changesets must reference the same TopDuContext.
+     */
+    DUChainChangeSet & operator<<(DUChainChangeSet & rhs);
 
     /**
     * Produce a reference to an existing object in this chain, and replace the
@@ -231,6 +246,8 @@ public:
      * Retrieve the list of object references and changes.
      */
     QList<DUChainRef*> objectRefs() const;
+    
+    const ReferencedTopDUContext & topDuContext() const;
 
 private:
     ReferencedTopDUContext m_topContext;
