@@ -47,9 +47,14 @@ public:
     QList<KDevelop::Declaration*> overrideSuperclasses;
     QMultiHash<Identifier, KDevelop::Declaration*> overriddenFunctions;
     QList<KDevelop::Declaration*> chosenOverrides;
+    QList<KDevelop::IndexedDeclaration> baseClasses;
     QVariantList selectedOverrides;
 };
 
+QList< KDevelop::IndexedDeclaration > KDevelop::OverridesPage::baseClasses() const {
+    return d->baseClasses;
+}
+
 OverridesPage::OverridesPage(QWizard* parent)
     : QWizardPage(parent)
     , d(new OverridesPagePrivate)
@@ -125,17 +130,13 @@ void OverridesPage::cleanupPage()
 
 void OverridesPage::fetchInheritance(const QString& inheritedObject)
 {
-    // TODO: properly strip qualifiers
-    QString identifier = inheritedObject;
-    identifier = identifier.remove("public ", Qt::CaseInsensitive).remove("protected ", Qt::CaseInsensitive).remove("private ", Qt::CaseInsensitive).simplified();
-
     KDevelop::DUChainReadLocker lock( DUChain::lock(), 100 );
     if(!lock.locked()) {
       kDebug() << "Failed to lock du-chain in time";
       return;
     }
 
-    PersistentSymbolTable::Declarations declarations = PersistentSymbolTable::self().getDeclarations( IndexedQualifiedIdentifier( QualifiedIdentifier(identifier)) );
+    PersistentSymbolTable::Declarations declarations = PersistentSymbolTable::self().getDeclarations( IndexedQualifiedIdentifier(parseParentClassId(inheritedObject)) );
 
     for (PersistentSymbolTable::Declarations::Iterator it = declarations.iterator(); it; ++it) {
         Declaration* decl = it->declaration();
@@ -145,10 +146,22 @@ void OverridesPage::fetchInheritance(const QString& inheritedObject)
         // Check if it's a class/struct/etc
         if (decl->type<StructureType>()) {
             fetchInheritanceFromClass(decl);
+            d->baseClasses << IndexedDeclaration(decl);
+            break;
         }
     }
 }
 
+KDevelop::QualifiedIdentifier KDevelop::OverridesPage::parseParentClassId(const QString& inheritedObject)
+{
+    // TODO: properly strip qualifiers
+    QString identifier = inheritedObject;
+    identifier = identifier.remove("public ", Qt::CaseInsensitive).remove("protected ", Qt::CaseInsensitive).remove("private ", Qt::CaseInsensitive).simplified();
+
+    return QualifiedIdentifier(identifier);
+}
+
+
 void OverridesPage::fetchInheritanceFromClass(KDevelop::Declaration* decl)
 {
     // Prevent recursion / duplication
@@ -219,6 +232,15 @@ void OverridesPage::addPotentialOverride(QTreeWidgetItem* classItem, KDevelop::D
         overrideItem->setCheckState( 2, function->isSignal() ? Qt::Checked : Qt::Unchecked );
         overrideItem->setCheckState( 3, function->isSlot() ? Qt::Checked : Qt::Unchecked );
     }
+    
+    ClassFunctionDeclaration* classFunction = dynamic_cast<ClassFunctionDeclaration*>(childDeclaration);
+    if(classFunction && classFunction->isAbstract()) {
+        overrideItem->setIcon(0, KIcon("flag-red"));
+        overrideItem->setCheckState(0, Qt::Checked);
+        overrideItem->setText(0, overrideItem->text(0) + " = 0");///@todo this is C++ specific
+        classItem->removeChild(overrideItem);
+        classItem->insertChild(0, overrideItem);
+    }
 }
 
 QTreeWidget* OverridesPage::overrideTree() const
