@@ -473,9 +473,20 @@ kDebug() << index << removed << removed2;
     uint listIndex = m_environmentListInfo.findIndex(url);
 
     if(listIndex) {
-      QMutexLocker lock(m_environmentListInfo.mutex()); //Lock the mutex to make sure the item isn't changed while it's being iterated
-      const EnvironmentInformationListItem* item = m_environmentListInfo.itemFromIndex(listIndex);
-      FOREACH_FUNCTION(uint topContextIndex, item->items) {
+      KDevVarLengthArray<uint> topContextIndices;
+      
+      {
+        //First store all the possible intices into the KDevVarLengthArray, so we can unlock the mutex before processing them.
+        
+        QMutexLocker lock(m_environmentListInfo.mutex()); //Lock the mutex to make sure the item isn't changed while it's being iterated
+        const EnvironmentInformationListItem* item = m_environmentListInfo.itemFromIndex(listIndex);
+        FOREACH_FUNCTION(uint topContextIndex, item->items)
+          topContextIndices << topContextIndex;
+      }
+      
+      //Process the indices in a separate step after copying them from the array, so we don't need m_environmentListInfo.mutex locked,
+      //and can call loadInformation(..) safely, which else might lead to a deadlock.
+      FOREACH_ARRAY(uint topContextIndex, topContextIndices) {
         KSharedPtr< ParsingEnvironmentFile > p = ParsingEnvironmentFilePointer(loadInformation(topContextIndex));
         if(p) {
          ret << p;
@@ -824,6 +835,7 @@ kDebug() << index << removed << removed2;
 
   ///Loads/gets the environment-information for the given top-context index, or returns zero if none exists
   ///@warning m_chainsMutex should NOT be locked when this is called, because it triggers I/O
+  ///@warning no other mutexes should be locked, as that may lead to a dedalock
   ParsingEnvironmentFile* loadInformation(uint topContextIndex) {
 
     ParsingEnvironmentFile* alreadyLoaded = findInformation(topContextIndex);
@@ -839,14 +851,13 @@ kDebug() << index << removed << removed2;
 
     const EnvironmentInformationItem& item(*m_environmentInfo.itemFromIndex(dataIndex));
 
-    QMutexLocker lock(&m_chainsMutex);
-    
     alreadyLoaded = findInformation(topContextIndex);
     if(alreadyLoaded)
       return alreadyLoaded;
     
     ParsingEnvironmentFile* ret = dynamic_cast<ParsingEnvironmentFile*>(DUChainItemSystem::self().create( (DUChainBaseData*)(((char*)&item) + sizeof(EnvironmentInformationItem)) ));
     if(ret) {
+      QMutexLocker lock(&m_chainsMutex);
       Q_ASSERT(ret->d_func()->classId);
       Q_ASSERT(ret->indexedTopContext().index() == topContextIndex);
       ParsingEnvironmentFilePointer retPtr(ret);
@@ -1366,7 +1377,7 @@ void DUChain::documentActivated(KDevelop::IDocument* doc)
     return;
   //Check whether the document has an attached environment-manager, and whether that one thinks the document needs to be updated.
   //If yes, update it.
-  DUChainWriteLocker lock( DUChain::lock() );
+  DUChainReadLocker lock( DUChain::lock() );
   QMutexLocker l(&sdDUChainPrivate->m_chainsMutex);
   TopDUContext* ctx = DUChainUtils::standardContextForUrl(doc->url());
   if(ctx && ctx->parsingEnvironmentFile())
@@ -1442,6 +1453,7 @@ void DUChain::documentLoadedPrepare(KDevelop::IDocument* doc)
       SmartConverter sc(&editor);
       
       if(standardContext->smartRange()) {
+        Q_ASSERT(standardContext->smartRange()->document() == doc->textDocument());
         kWarning() << "Strange: context already has smart-range! Probably another document is already open for it. Deconverting";
         sc.deconvertDUChain(standardContext);
       }
@@ -1454,19 +1466,36 @@ void DUChain::documentLoadedPrepare(KDevelop::IDocument* doc)
 
     bool needsUpdate = standardContext->parsingEnvironmentFile() && standardContext->parsingEnvironmentFile()->needsUpdate();
     if(!needsUpdate) {
+
         //Only apply the highlighting if we don't need to update, else we might highlight total crap
-        foreach( KDevelop::ILanguage* language, languages)
-          if(language->languageSupport() && language->languageSupport()->codeHighlighting())
-            language->languageSupport()->codeHighlighting()->highlightDUChain(standardContext);
+        //Do instant highlighting only if all imports are loaded, to make sure that we don't block the user-interface too long
+        //Else the highlighting will be done in the background-thread
+        //This is not exactly right, as the direct imports don't necessarily equal the real imports used by uses
+        //but it approximates the correct behavior.
+        bool allImportsLoaded = true;
+        foreach(DUContext::Import import, standardContext->importedParentContexts())
+          if(!import.indexedContext().indexedTopContext().isLoaded())
+            allImportsLoaded = false;
+
+        if(allImportsLoaded) {
+          foreach( KDevelop::ILanguage* language, languages)
+            if(language->languageSupport() && language->languageSupport()->codeHighlighting())
+              language->languageSupport()->codeHighlighting()->highlightDUChain(standardContext);
+          kDebug() << "highlighted" << doc->url() << "in foreground";
+          return;
+        }
     }else{
       kDebug() << "not highlighting the duchain because the documents needs an update";
     }
     
-    if(needsUpdate || !(standardContext->features() & TopDUContext::AllDeclarationsContextsAndUses))
+    if(needsUpdate || !(standardContext->features() & TopDUContext::AllDeclarationsContextsAndUses)) {
       ICore::self()->languageController()->backgroundParser()->addDocument(doc->url(), (TopDUContext::Features)(TopDUContext::AllDeclarationsContextsAndUses | TopDUContext::ForceUpdate));
-  }else{
-    ICore::self()->languageController()->backgroundParser()->addDocument(doc->url(), TopDUContext::AllDeclarationsContextsAndUses);
+      return;
+    }
   }
+    
+  //Add for highlighting etc.
+  ICore::self()->languageController()->backgroundParser()->addDocument(doc->url(), TopDUContext::AllDeclarationsContextsAndUses);
 }
 
 void DUChain::documentRenamed(KDevelop::IDocument* doc)
