@@ -45,12 +45,12 @@
 using namespace KDevelop;
 using namespace KTextEditor;
 
-CodeCompletionModel::CompletionProperties DUChainUtils::completionProperties(Declaration* dec)
+CodeCompletionModel::CompletionProperties DUChainUtils::completionProperties(const Declaration* dec)
 {
   CodeCompletionModel::CompletionProperties p;
 
   if(dec->context()->type() == DUContext::Class) {
-    if (ClassMemberDeclaration* member = dynamic_cast<ClassMemberDeclaration*>(dec)) {
+    if (const ClassMemberDeclaration* member = dynamic_cast<const ClassMemberDeclaration*>(dec)) {
       switch (member->accessPolicy()) {
         case Declaration::Public:
           p |= CodeCompletionModel::Public;
@@ -78,7 +78,7 @@ CodeCompletionModel::CompletionProperties DUChainUtils::completionProperties(Dec
     }
   }
 
-  if (AbstractFunctionDeclaration* function = dynamic_cast<AbstractFunctionDeclaration*>(dec)) {
+  if (const AbstractFunctionDeclaration* function = dynamic_cast<const AbstractFunctionDeclaration*>(dec)) {
     p |= CodeCompletionModel::Function;
     if (function->isVirtual())
       p |= CodeCompletionModel::Virtual;
@@ -222,7 +222,7 @@ QIcon DUChainUtils::iconForProperties(KTextEditor::CodeCompletionModel::Completi
   return KIcon();
 }
 
-QIcon DUChainUtils::iconForDeclaration(Declaration* dec)
+QIcon DUChainUtils::iconForDeclaration(const Declaration* dec)
 {
   return iconForProperties(completionProperties(dec));
 }
@@ -332,17 +332,17 @@ void DUChainUtils::collectItems( DUContext* context, DUChainItemFilter& filter )
   QVector<DUContext*> children = context->childContexts();
   QVector<Declaration*> localDeclarations = context->localDeclarations();
 
-  QVector<DUContext*>::const_iterator childIt = children.begin();
-  QVector<Declaration*>::const_iterator declIt = localDeclarations.begin();
+  QVector<DUContext*>::const_iterator childIt = children.constBegin();
+  QVector<Declaration*>::const_iterator declIt = localDeclarations.constBegin();
 
-  while(childIt != children.end() || declIt != localDeclarations.end()) {
+  while(childIt != children.constEnd() || declIt != localDeclarations.constEnd()) {
 
     DUContext* child = 0;
-    if(childIt != children.end())
+    if(childIt != children.constEnd())
       child = *childIt;
 
     Declaration* decl = 0;
-    if(declIt != localDeclarations.end())
+    if(declIt != localDeclarations.constEnd())
       decl = *declIt;
 
     if(decl) {
@@ -420,6 +420,9 @@ QList<Declaration*> DUChainUtils::getInheriters(const Declaration* decl, uint& m
       
       DUContext* imp = importer.data();
       
+      if(!imp)
+        continue;
+      
       if(imp->type() == DUContext::Class && imp->owner())
         ret << imp->owner();
 
@@ -511,9 +514,12 @@ Declaration* DUChainUtils::getOverridden(const Declaration* decl) {
   
   QList<Declaration*> decls;
 
-  foreach(const DUContext::Import &import, decl->context()->importedParentContexts())
-    decls += import.context(decl->topContext())->findDeclarations(QualifiedIdentifier(decl->identifier()), 
+  foreach(const DUContext::Import &import, decl->context()->importedParentContexts()) {
+    DUContext* ctx = import.context(decl->topContext());
+    if(ctx)
+      decls += ctx->findDeclarations(QualifiedIdentifier(decl->identifier()), 
                                             SimpleCursor::invalid(), decl->abstractType(), decl->topContext(), DUContext::DontSearchInParent);
+  }
 
   foreach(Declaration* found, decls) {
     const ClassFunctionDeclaration* foundClassFunDecl = dynamic_cast<const ClassFunctionDeclaration*>(found);
