@@ -1,5 +1,6 @@
 /* This file is part of KDevelop
     Copyright 2006 Hamish Rodda <rodda@kde.org>
+    Copyright 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,6 +29,7 @@
 #include <kdebug.h>
 
 #include "../languageexport.h"
+#include "referencecounting.h"
 
 //We use shared d-pointers, which is even better than a d-pointer, but krazy probably won't get it, so exclude the test.
 //krazy:excludeall=dpointer
@@ -35,7 +37,7 @@
 namespace KDevelop
 {
 
-class TypeIdentifier;
+class IndexedTypeIdentifier;
 class Identifier;
 class QualifiedIdentifier;
 template<bool>
@@ -44,62 +46,65 @@ template<bool>
 class IdentifierPrivate;
 class IndexedString;
 
-//A helper-class to store an identifier by index in a type-safe way. Will be extended to do reference-counting at some point.
-//The difference to Identifier is that this class only stores the index of an identifier that is in the repository, without any dynamic
-//abilities or access to the contained data.
-struct KDEVPLATFORMLANGUAGE_EXPORT IndexedIdentifier {
+///A helper-class to store an identifier by index in a type-safe way. 
+///The difference to Identifier is that this class only stores the index of an identifier that is in the repository, without any dynamic
+///abilities or access to the contained data.
+///This class does "disk reference counting"
+///@warning Do not use this after QCoreApplication::aboutToQuit() has been emitted, items that are not disk-referenced will be invalid at that point
+struct KDEVPLATFORMLANGUAGE_EXPORT IndexedIdentifier : public ReferenceCountManager {
   IndexedIdentifier();
   IndexedIdentifier(const Identifier& id);
+  IndexedIdentifier(const IndexedIdentifier& rhs);
   IndexedIdentifier& operator=(const Identifier& id);
+  IndexedIdentifier& operator=(const IndexedIdentifier& rhs);
+  ~IndexedIdentifier();
   bool operator==(const IndexedIdentifier& rhs) const;
   bool operator!=(const IndexedIdentifier& rhs) const;
   bool operator==(const Identifier& id) const;
 
+  
   bool isEmpty() const;
 
   Identifier identifier() const;
   operator Identifier() const;
 
+  uint getIndex() const {
+    return index;
+  }
+  
+  private:
   unsigned int index;
 };
 
-//A helper-class to store an identifier by index in a type-safe way. Will be extended to do reference-counting at some point.
-//The difference to QualifiedIdentifier is that this class only stores the index of an identifier that is in the repository, without any dynamic
-//abilities or access to the contained data.
-struct KDEVPLATFORMLANGUAGE_EXPORT IndexedQualifiedIdentifier {
+///A helper-class to store an identifier by index in a type-safe way.
+///The difference to QualifiedIdentifier is that this class only stores the index of an identifier that is in the repository, without any dynamic
+///abilities or access to the contained data.
+///This class does "disk reference counting"
+///@warning Do not use this after QCoreApplication::aboutToQuit() has been emitted, items that are not disk-referenced will be invalid at that point
+struct KDEVPLATFORMLANGUAGE_EXPORT IndexedQualifiedIdentifier : public ReferenceCountManager {
   IndexedQualifiedIdentifier();
   IndexedQualifiedIdentifier(const QualifiedIdentifier& id);
+  IndexedQualifiedIdentifier(const IndexedQualifiedIdentifier& rhs);
   IndexedQualifiedIdentifier& operator=(const QualifiedIdentifier& id);
+  IndexedQualifiedIdentifier& operator=(const IndexedQualifiedIdentifier& id);
+  ~IndexedQualifiedIdentifier();
   bool operator==(const IndexedQualifiedIdentifier& rhs) const;
   bool operator==(const QualifiedIdentifier& id) const;
 
   bool operator<(const IndexedQualifiedIdentifier& rhs) const {
     return index < rhs.index;
   }
-  
+
   bool isValid() const;
 
   QualifiedIdentifier identifier() const;
   operator QualifiedIdentifier() const;
 
-  uint index;
-};
-
-//A helper-class to store an identifier by index in a type-safe way. Will be extended to do reference-counting at some point.
-//The difference to QualifiedIdentifier is that this class only stores the index of an identifier that is in the repository, without any dynamic
-//abilities or access to the contained data.
-struct KDEVPLATFORMLANGUAGE_EXPORT IndexedTypeIdentifier {
-  IndexedTypeIdentifier();
-  IndexedTypeIdentifier(const TypeIdentifier& id);
-  IndexedTypeIdentifier& operator=(const TypeIdentifier& id);
-  bool operator==(const IndexedTypeIdentifier& rhs) const;
-  bool operator==(const TypeIdentifier& id) const;
-
-  bool isValid() const;
-
-  TypeIdentifier identifier() const;
-  operator TypeIdentifier() const;
-
+  uint getIndex() const {
+    return index;
+  }
+  
+  private:
   uint index;
 };
 
@@ -112,6 +117,7 @@ public:
   /**
    * @param start The position in the given string where to start searching for the identifier(optional).
    * @param takenRange If this is nonzero, it will be filled with the length of the range from the beginning of the given string, that was used to construct this identifier.(optional)
+   * @warning The identifier is parsed in a C++-similar way, and the result may not be what you expect. If you want to prevent that parsing, use the constructor that takes IndexedString.
    * */
   explicit Identifier(const QString& str, uint start = 0, uint* takenRange = 0);
   ///Preferred constructor, ise this if you already have an IndexedString available. This does not decompose the given string.
@@ -145,11 +151,11 @@ public:
   bool nameEquals(const Identifier& rhs) const;
 
   //Expensive
-  TypeIdentifier templateIdentifier(int num) const;
+  IndexedTypeIdentifier templateIdentifier(int num) const;
   uint templateIdentifiersCount() const;
-  void appendTemplateIdentifier(const TypeIdentifier& identifier);
+  void appendTemplateIdentifier(const IndexedTypeIdentifier& identifier);
   void clearTemplateIdentifiers();
-  void setTemplateIdentifiers(const QList<TypeIdentifier>& templateIdentifiers);
+  void setTemplateIdentifiers(const QList<IndexedTypeIdentifier>& templateIdentifiers);
 
   QString toString() const;
 
@@ -191,7 +197,7 @@ private:
 class KDEVPLATFORMLANGUAGE_EXPORT QualifiedIdentifier
 {
 public:
-  explicit QualifiedIdentifier(const QString& id);
+  explicit QualifiedIdentifier(const QString& id, bool isExpression = false);
   explicit QualifiedIdentifier(const Identifier& id);
   QualifiedIdentifier(const QualifiedIdentifier& id);
   QualifiedIdentifier(uint index);
@@ -218,10 +224,11 @@ public:
   /**
    * Copy the leftmost \a len number of identifiers.
    *
-   * @param len The number of identifiers to copy.
+   * @param len The number of identifiers to copy, or if negative, the number of identifiers to omit from the right
    * */
-  inline QualifiedIdentifier left(int len) const { return mid(0, len); }
+  inline QualifiedIdentifier left(int len) const { return mid(0, len > 0 ? len : count() + len); }
 
+  ///@todo Remove this flag
   bool explicitlyGlobal() const;
   void setExplicitlyGlobal(bool eg);
   bool isQualified() const;
@@ -249,20 +256,12 @@ public:
 
   //Returns a QualifiedIdentifier with this one appended to the other. It is explicitly global if either this or base is.
   QualifiedIdentifier merge(const QualifiedIdentifier& base) const;
-//   //The returned identifier will have explicitlyGlobal() set to false
-//   QualifiedIdentifier strip(const QualifiedIdentifier& unwantedBase) const;
-
-  /**
-   * A more complex comparison than operator==(..).
-   * It does respect the isExpression() flag, and optionally the explicitlyGlobal flag.
-   * */
-  bool isSame(const QualifiedIdentifier& rhs, bool ignoreExplicitlyGlobal=true) const;
 
   /**
    * Computes the hash-value that would be created with a qualified identifier with hash-value @param leftHash of size @param leftSize
    * with @param appendIdentifier appended as an identifier
    * */
-  static uint combineHash(uint leftHash, uint leftSize, Identifier appendIdentifier);
+//   static uint combineHash(uint leftHash, uint leftSize, Identifier appendIdentifier);
 
   /**The comparison-operators do not respect explicitlyGlobal and isExpression, they only respect the real scope.
    * This is for convenient use in hash-tables etc.
@@ -270,20 +269,15 @@ public:
   bool operator==(const QualifiedIdentifier& rhs) const;
   bool operator!=(const QualifiedIdentifier& rhs) const;
   QualifiedIdentifier& operator=(const QualifiedIdentifier& rhs);
-#if 0
-  enum MatchTypes {
-    NoMatch        /**< matches no identifier */,
-    EndsWith       /**< The current identifier ends with the one given to the match function */,
-    TargetEndsWith /**< The identifier given to the match function ends with the current identifier */,
-    ExactMatch     /**< matches if the identifiers match exactly */
-  };
 
-  MatchTypes match(const Identifier& other) const;
-  MatchTypes match(const QualifiedIdentifier& other) const;
-#endif
   bool beginsWith(const QualifiedIdentifier& other) const;
 
   uint index() const;
+  
+  /**
+   * Returns true if this qualified identifier is already in the persistent identifier repository
+   */
+  bool inRepository() const;
 
   /**
     * kDebug(9505) stream operator.  Writes this identifier to the debug output in a nicely formatted way.
@@ -315,25 +309,28 @@ protected:
 };
 
 /**
- * Extends QualifiedIdentifier by:
+ * Extends IndexedQualifiedIdentifier by:
  * - Arbitrary count of pointer-poperators with cv-qualifiers
  * - Reference operator
  * All the properties set here are respected in the hash value.
+ *
  * */
-class KDEVPLATFORMLANGUAGE_EXPORT TypeIdentifier : public QualifiedIdentifier
+class KDEVPLATFORMLANGUAGE_EXPORT IndexedTypeIdentifier
 {
 public:
   ///Variables like pointerDepth, isReference, etc. are not parsed from the string, so this parsing is quite limited.
-  TypeIdentifier();
-  TypeIdentifier(const QString& str);
-  TypeIdentifier(const QualifiedIdentifier& id);
-  TypeIdentifier(const TypeIdentifier& id);
-  TypeIdentifier(uint index);
+  explicit IndexedTypeIdentifier(IndexedQualifiedIdentifier identifier = IndexedQualifiedIdentifier());
+  explicit IndexedTypeIdentifier(const QString& identifer, bool isExpression = false);
+  
   bool isReference() const;
   void setIsReference(bool);
 
   bool isConstant() const;
   void setIsConstant(bool);
+  
+  IndexedQualifiedIdentifier identifier() const ;
+  
+  void setIdentifier(IndexedQualifiedIdentifier id);
 
   ///Returns the pointer depth. Example for C++: "char*" has pointer-depth 1, "char***" has pointer-depth 3
   int pointerDepth() const;
@@ -346,18 +343,24 @@ public:
   bool isConstPointer(int depthNumber) const;
   void setIsConstPointer(int depthNumber, bool constant);
 
-  bool isSame(const TypeIdentifier& rhs, bool ignoreExplicitlyGlobal=true) const;
-
   QString toString(bool ignoreExplicitlyGlobal = false) const;
 
+  uint hash() const;
+  
   /**The comparison-operators do not respect explicitlyGlobal and isExpression, they only respect the real scope.
    * This is for convenient use in hash-tables etc.
    * */
-  bool operator==(const TypeIdentifier& rhs) const;
-  bool operator!=(const TypeIdentifier& rhs) const;
+  bool operator==(const IndexedTypeIdentifier& rhs) const;
+  bool operator!=(const IndexedTypeIdentifier& rhs) const;
+  private:
+    IndexedQualifiedIdentifier m_identifier;
+    bool m_isConstant : 1;
+    bool m_isReference : 1;
+    uint m_pointerDepth : 5;
+    uint m_pointerConstMask : 25;
 };
 
-KDEVPLATFORMLANGUAGE_EXPORT uint qHash(const TypeIdentifier& id);
+KDEVPLATFORMLANGUAGE_EXPORT uint qHash(const IndexedTypeIdentifier& id);
 KDEVPLATFORMLANGUAGE_EXPORT uint qHash(const QualifiedIdentifier& id);
 KDEVPLATFORMLANGUAGE_EXPORT uint qHash(const Identifier& id);
 
