@@ -229,7 +229,9 @@ PersistentSymbolTable::PersistentSymbolTable() : d(new PersistentSymbolTablePriv
 
 PersistentSymbolTable::~PersistentSymbolTable()
 {
-  delete d;
+  //Workaround for a strange destruction-order related crash duing shutdown
+  //We just let the data leak. This doesn't hurt, as there is no meaningful destructors.
+//   delete d;
 }
 
 void PersistentSymbolTable::addDeclaration(const IndexedQualifiedIdentifier& id, const IndexedDeclaration& declaration)
@@ -345,8 +347,8 @@ PersistentSymbolTable::FilteredDeclarationIterator PersistentSymbolTable::getFil
   
   CachedIndexedRecursiveImports cachedImports;
   
-  QHash<TopDUContext::IndexedRecursiveImports, CachedIndexedRecursiveImports>::const_iterator it = d->m_importsCache.find(visibility);
-  if(it != d->m_importsCache.end()) {
+  QHash<TopDUContext::IndexedRecursiveImports, CachedIndexedRecursiveImports>::const_iterator it = d->m_importsCache.constFind(visibility);
+  if(it != d->m_importsCache.constEnd()) {
     cachedImports = *it;
   }else{
     cachedImports = CachedIndexedRecursiveImports(visibility.set().stdSet());
@@ -357,8 +359,8 @@ PersistentSymbolTable::FilteredDeclarationIterator PersistentSymbolTable::getFil
   {
     //Do visibility caching
     CacheEntry<IndexedDeclaration>& cached(d->m_declarationsCache[id]);
-    CacheEntry<IndexedDeclaration>::DataHash::const_iterator cacheIt = cached.m_hash.find(visibility);
-    if(cacheIt != cached.m_hash.end())
+    CacheEntry<IndexedDeclaration>::DataHash::const_iterator cacheIt = cached.m_hash.constFind(visibility);
+    if(cacheIt != cached.m_hash.constEnd())
       return FilteredDeclarationIterator(Declarations::Iterator(cacheIt->constData(), cacheIt->size(), -1), cachedImports);
 
     CacheEntry<IndexedDeclaration>::DataHash::iterator insertIt = cached.m_hash.insert(visibility, KDevVarLengthArray<IndexedDeclaration>());
@@ -399,8 +401,8 @@ PersistentSymbolTable::FilteredDUContextIterator PersistentSymbolTable::getFilte
   
   CachedIndexedRecursiveImports cachedImports;
   
-  QHash<TopDUContext::IndexedRecursiveImports, CachedIndexedRecursiveImports>::const_iterator it = d->m_importsCache.find(visibility);
-  if(it != d->m_importsCache.end()) {
+  QHash<TopDUContext::IndexedRecursiveImports, CachedIndexedRecursiveImports>::const_iterator it = d->m_importsCache.constFind(visibility);
+  if(it != d->m_importsCache.constEnd()) {
     cachedImports = *it;
   }else{
     cachedImports = CachedIndexedRecursiveImports(visibility.set().stdSet());
@@ -411,8 +413,8 @@ PersistentSymbolTable::FilteredDUContextIterator PersistentSymbolTable::getFilte
   {
     //Do visibility caching
     CacheEntry<IndexedDUContext>& cached(d->m_contextsCache[id]);
-    CacheEntry<IndexedDUContext>::DataHash::const_iterator cacheIt = cached.m_hash.find(visibility);
-    if(cacheIt != cached.m_hash.end())
+    CacheEntry<IndexedDUContext>::DataHash::const_iterator cacheIt = cached.m_hash.constFind(visibility);
+    if(cacheIt != cached.m_hash.constEnd())
       return FilteredDUContextIterator(Contexts::Iterator(cacheIt->constData(), cacheIt->size(), -1), cachedImports);
 
     CacheEntry<IndexedDUContext>::DataHash::iterator insertIt = cached.m_hash.insert(visibility, KDevVarLengthArray<IndexedDUContext>());
