@@ -35,7 +35,7 @@ namespace KDevelop {
 
 uint staticItemRepositoryVersion() {
   //Increase this to reset incompatible item-repositories
-  return 58;
+  return 60;
 }
 
 AbstractItemRepository::~AbstractItemRepository() {
@@ -114,9 +114,11 @@ QPair<QString, KLockFile::Ptr> allocateRepository() {
 ///The global item-repository registry that is used by default
 ItemRepositoryRegistry& allocateGlobalItemRepositoryRegistry() {
   QPair<QString, KLockFile::Ptr> repo = allocateRepository();
-    
-  static ItemRepositoryRegistry global(repo.first, repo.second);
-  return global;
+  
+  ///We intentionally leak the registry, to prevent problems in the destruction order, where
+  ///the actual repositories might get deleted later than the repository registry.
+  static ItemRepositoryRegistry* global = new ItemRepositoryRegistry(repo.first, repo.second);
+  return *global;
 }
 
 ///The global item-repository registry that is used by default
@@ -303,7 +305,7 @@ void ItemRepositoryRegistry::store() {
   if(f.open(QIODevice::WriteOnly)) {
     f.resize(0);
     QDataStream stream(&f);
-    for(QMap<QString, QAtomicInt*>::const_iterator it = m_customCounters.begin(); it != m_customCounters.end(); ++it) {
+    for(QMap<QString, QAtomicInt*>::const_iterator it = m_customCounters.constBegin(); it != m_customCounters.constEnd(); ++it) {
       stream << it.key();
       stream << it.value()->fetchAndAddRelaxed(0);
     }
