@@ -31,6 +31,7 @@ class KSharedPtr;
 
 namespace KDevelop
 {
+  class IAstContainer;
   class QualifiedIdentifier;
   class DUChain;
   class ParsingEnvironmentFile;
@@ -217,11 +218,13 @@ public:
     ///This flag can not be set on a context, it is only used as a parameter to several updating functions. When you set it
     ///on a top-context, its flag will be AllDeclarationsContextsAndUses.
     AllDeclarationsContextsAndUsesForRecursive = 8 + AllDeclarationsContextsAndUses,
-    ForceUpdate = 16, //This flag can not be set on a context, but is only used during updating
-    ForceUpdateRecursive = ForceUpdate | 32  //This flag can not be set on a context, but is only used during updating
+    AST = 16,  //Use this flag if you want to signalize that the IAstContainer needs to be there
+    ForceUpdate = 32, //This flag can not be set on a context, but is only used during updating
+    ForceUpdateRecursive = ForceUpdate | 64 //This flag can not be set on a context, but is only used during updating
   };
   
   Features features() const;
+  ///Set the features of this top-context. These features are ignored: AST, ForceUpdate, and ForeceUpdateRecursive.
   void setFeatures(Features);
 
   /**
@@ -249,18 +252,31 @@ public:
    * */
   void clearUsedDeclarationIndices();
 
-  /// Returns the language for this top-context. If the string is empty, the language is unknown.
-  IndexedString language() const;
-  
-  ///Sets the language for this top-context. Each top-context should get the language assigned that can by used
-  ///in order to load the language using ILanguageController.
-  void setLanguage(IndexedString language);
-  
   /**
    * Use flags to mark top-contexts for special behavior. Any flags above LastFlag may be used for language-specific stuff.
    * */
   Flags flags() const;
   void setFlags(Flags f);
+  
+  /**
+   * Returns the AST Container, that contains the AST created during parsing.
+   * This is only created if you request the AST feature for parsing.
+   * It may be discarded at any time. Every update without the AST feature will discard it.
+   * The actual contents is language-specific.
+   *
+   * @todo Figure out logic to get rid of AST when it is not needed/useful
+   */
+  KSharedPtr<IAstContainer> ast() const;
+  
+  /**
+   * Sets the AST Container.
+  */
+  void setAst(KSharedPtr<IAstContainer> ast);
+  
+  /**
+   * Utility function to clear the AST Container
+   */
+  void clearAst();
 
   ///@param temporary If this is true, importers of this context will not be notified of the new imports. This greatly increases performance while removing the context,
   ///but creates in inconsistent import-structure. Therefore it is only suitable for temporary imports. These imports will not be visible from contexts that import this one.
