@@ -35,13 +35,15 @@
 #include <kpluginloader.h>
 #include <kactioncollection.h>
 #include <kmimetype.h>
+#include <kparts/mainwindow.h>
 #include <kio/copyjob.h>
 #include <kio/netaccess.h>
+#include <kde_file.h>
 
 #include <interfaces/icore.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iplugincontroller.h>
-#include <vcs/vcsmapping.h>
+#include <interfaces/iuicontroller.h>
 #include <vcs/vcslocation.h>
 #include <vcs/vcsjob.h>
 #include <vcs/interfaces/icentralizedversioncontrol.h>
@@ -58,7 +60,6 @@ using KDevelop::IDistributedVersionControl;
 using KDevelop::IPlugin;
 using KDevelop::VcsJob;
 using KDevelop::VcsLocation;
-using KDevelop::VcsMapping;
 
 K_PLUGIN_FACTORY(AppWizardFactory,
     registerPlugin<AppWizardPlugin>();
@@ -105,6 +106,8 @@ void AppWizardPlugin::slotNewProject()
         if (!project.isEmpty())
         {
             core()->projectController()->openProject(KUrl::fromPath(project));
+        } else {
+            KMessageBox::error( KDevelop::ICore::self()->uiController()->activeMainWindow(), i18n("Could not create project from template\n"), i18n("Failed to create project") );
         }
     }
 }
@@ -148,21 +151,21 @@ bool initializeDVCS(IDistributedVersionControl* dvcs, const ApplicationInfo& inf
     }
     kDebug() << "Initializing DVCS repository:" << dest.toLocalFile();
 
-    job = dvcs->add(KUrl::List(dest), IBasicVersionControl::Recursive);
+    job = dvcs->add(KUrl::List(dest), KDevelop::IBasicVersionControl::Recursive);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded)
     {
         vcsError(i18n("Could not add files to the DVCS repository"), scratchArea, dest);
         return false;
     }
     job = dvcs->commit(QString("initial project import from KDevelop"), KUrl::List(dest),
-                            IBasicVersionControl::Recursive);
+                            KDevelop::IBasicVersionControl::Recursive);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded)
     {
-        vcsError(i18n("Could not import project into") + dvcs->name(), scratchArea, dest);
+        vcsError(i18n("Could not import project into %1.", dvcs->name()), scratchArea, dest);
         return false;
     }
 
-    return true; // We'r good
+    return true; // We're good
 }
 
 /*! Setup version control for a new project defined by @p info. Use @p scratchArea for temporary files  */
@@ -170,33 +173,20 @@ bool initializeCVCS(ICentralizedVersionControl* cvcs, const ApplicationInfo& inf
 {
     Q_ASSERT(cvcs);
 
-    KUrl dest = info.location;
-    VcsMapping import;
-    VcsLocation srcloc = info.importInformation.sourceLocations().first();
-    import.addMapping( VcsLocation( KUrl( scratchArea.name() ) ),
-                       info.importInformation.destinationLocation( srcloc ),
-                       info.importInformation.mappingFlag( srcloc ) );
-
-    VcsLocation importLoc(KUrl( scratchArea.name()));
-    kDebug() << "Importing" << srcloc.localUrl() << "to"
-             << import.destinationLocation(importLoc).repositoryServer();
-    kDebug() << "Using temp dir" << scratchArea.name()
-             << import.sourceLocations().first().localUrl();
-    VcsLocation checkoutLoc = info.checkoutInformation.sourceLocations().first();
-    kDebug() << "Checking out" << checkoutLoc.repositoryServer()
-             << "to" << info.checkoutInformation.destinationLocation(checkoutLoc).localUrl();
-
-    VcsJob* job = cvcs->import( import, info.importCommitMessage );
-    if(job && job->exec() && job->status() == VcsJob::JobSucceeded )
-    {
-        VcsJob* job = cvcs->checkout( info.checkoutInformation );
+    kDebug() << "Importing" << info.sourceLocation << "to"
+             << info.repository.repositoryServer();
+    VcsJob* job = cvcs->import( info.importCommitMessage, info.sourceLocation, info.repository);
         if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded )
         {
-            vcsError(i18n("Could not checkout imported project"), scratchArea, dest);
+        vcsError(i18n("Could not import project"), scratchArea, info.repository.repositoryServer());
             return false;
         }
-    } else {
-        vcsError(i18n("Could not import project"), scratchArea, dest);
+
+    kDebug() << "Checking out";
+    job = cvcs->createWorkingCopy( info.repository, info.sourceLocation, IBasicVersionControl::Recursive);
+    if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded )
+    {
+        vcsError(i18n("Could not checkout imported project"), scratchArea, info.repository.repositoryServer());
         return false;
     }
 
@@ -425,8 +415,8 @@ bool AppWizardPlugin::copyFileAndExpandMacros(const QString &source, const QStri
                 output << KMacroExpander::expandMacros(line, m_variables) << "\n";
             }
             // Preserve file mode...
-            struct stat fmode;
-            ::fstat(inputFile.handle(), &fmode);
+            KDE_struct_stat fmode;
+            KDE_fstat(inputFile.handle(), &fmode);
             ::fchmod(outputFile.handle(), fmode.st_mode);
             return true;
         }
