@@ -121,6 +121,7 @@ ClassTree::ClassTree(QWidget* parent, ClassBrowserPlugin* plugin)
   , m_plugin(plugin)
 {
   header()->hide();
+  setIndentation(10);
 
   connect(this, SIGNAL(activated(const QModelIndex&)), SLOT(itemActivated(const QModelIndex&)));
 }
@@ -184,6 +185,11 @@ void ClassTree::itemActivated(const QModelIndex& index)
 
     m_plugin->core()->documentController()->openDocument(url, range.start());
   }
+  
+  if(isExpanded(index))
+      collapse(index);
+  else
+      expand(index);
 }
 
 void ClassTree::highlightIdentifier(KDevelop::IndexedQualifiedIdentifier a_id)
