@@ -23,6 +23,7 @@
 #include "problemreporterplugin.h"
 
 #include <QTreeWidget>
+#include <QMenu>
 
 #include <klocale.h>
 #include <kpluginfactory.h>
@@ -44,6 +45,12 @@
 
 #include "problemhighlighter.h"
 #include "problemwidget.h"
+#include <interfaces/context.h>
+#include <language/interfaces/editorcontext.h>
+#include <language/duchain/duchainutils.h>
+#include <interfaces/contextmenuextension.h>
+#include <interfaces/iassistant.h>
+#include <kaction.h>
 
 K_PLUGIN_FACTORY(KDevProblemReporterFactory, registerPlugin<ProblemReporterPlugin>(); )
 K_EXPORT_PLUGIN(KDevProblemReporterFactory(KAboutData("kdevproblemreporter","kdevproblemreporter", ki18n("Problem Reporter"), "0.1", ki18n("Shows errors in source code"), KAboutData::License_GPL)))
@@ -98,6 +105,8 @@ void ProblemReporterPlugin::unload()
 
 void ProblemReporterPlugin::documentAboutToBeDeleted(KTextEditor::Document* doc)
 {
+  if(!doc)
+      return;
   QMutableHashIterator<IndexedString, ProblemHighlighter*> it = m_highlighters;
 
   IndexedString url(doc->url().pathOrUrl());
@@ -139,6 +148,45 @@ void ProblemReporterPlugin::parseJobFinished(KDevelop::ParseJob* parseJob)
     updateReady(parseJob->document(), parseJob->duChain());
 }
 
+KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDevelop::Context* context) {
+  KDevelop::ContextMenuExtension extension;
+  
+  KDevelop::EditorContext* editorContext = dynamic_cast<KDevelop::EditorContext*>(context);
+  if(editorContext) {
+      DUChainReadLocker lock(DUChain::lock(), 1000);
+      if(!lock.locked()) {
+        kDebug() << "failed to lock duchain in time";
+        return extension;
+      }
+      
+    QList<QAction*> actions;
+    
+    TopDUContext* top = DUChainUtils::standardContextForUrl(editorContext->url());
+    if(top) {
+      foreach(KDevelop::ProblemPointer problem, top->problems()) {
+        if(problem->range().contains(KDevelop::SimpleCursor(editorContext->position()))) {
+          KDevelop::IAssistant::Ptr solution = problem ->solutionAssistant();
+          if(solution) {
+            foreach(KDevelop::IAssistantAction::Ptr action, solution->actions())
+              actions << action->toKAction();
+          }
+        }
+      }
+    }
+    
+    if(!actions.isEmpty()) {
+      QAction* menuAction = new QAction(i18n("Solve Problem"), 0);
+      QMenu* menu(new QMenu(i18n("Solve Problem"), 0));
+      menuAction->setMenu(menu);
+      foreach(QAction* action, actions)
+        menu->addAction(action);
+      
+      extension.addAction(ContextMenuExtension::ExtensionGroup, menuAction);
+    }
+  }
+  return extension;
+}
+
 #include "problemreporterplugin.moc"
 
 // kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
