@@ -69,6 +69,10 @@
 #include "customlistquickopen.h"
 #include <language/duchain/functiondefinition.h>
 #include <qmenu.h>
+#include <qdesktopwidget.h>
+#include <util/activetooltip.h>
+#include <qboxlayout.h>
+#include <language/util/navigationtooltip.h>
 
 using namespace KDevelop;
 
@@ -178,18 +182,31 @@ QString cursorItemText() {
   return QString();
 }
 
-QuickOpenWidgetHandler::QuickOpenWidgetHandler( QString title, QuickOpenModel* model, const QStringList& initialItems, const QStringList& initialScopes, bool listOnly, bool noSearchField ) : m_model(model), m_expandedTemporary(false) {
-  m_dialog = new KDialog( ICore::self()->uiController()->activeMainWindow() );
-  m_dialog->setInitialSize(QSize(800, 400));
-  m_dialog->setButtons( KDialog::Ok | KDialog::Cancel );
+QWidget* QuickOpenPlugin::createQuickOpenLineWidget()
+{
+  return new QuickOpenLineEdit;
+}
 
-  o.setupUi( m_dialog->mainWidget() );
+void QuickOpenWidget::showStandardButtons(bool show)
+{
+  if(show) {
+    o.okButton->show();
+    o.cancelButton->show();
+  }else{
+    o.okButton->hide();
+    o.cancelButton->hide();
+  }
+}
+
+QuickOpenWidget::QuickOpenWidget( QString title, QuickOpenModel* model, const QStringList& initialItems, const QStringList& initialScopes, bool listOnly, bool noSearchField ) : m_model(model), m_expandedTemporary(false) {
+
+  o.setupUi( this );
   o.list->header()->hide();
   o.list->setRootIsDecorated( false );
   o.list->setVerticalScrollMode( QAbstractItemView::ScrollPerItem );
+  
   connect(o.list->verticalScrollBar(), SIGNAL(valueChanged(int)), m_model, SLOT(placeExpandingWidgets()));
 
-  m_dialog->setWindowTitle(title);
   o.searchLine->setFocus();
 
   o.list->setItemDelegate( new QuickOpenDelegate( m_model, o.list ) );
@@ -233,10 +250,11 @@ QuickOpenWidgetHandler::QuickOpenWidgetHandler( QString title, QuickOpenModel* m
     o.label_2->hide();
   }
 
-  if( noSearchField ) {
-    o.searchLine->hide();
-    o.searchLabel->hide();
-  }
+  showSearchField(!noSearchField);
+  
+  o.okButton->hide();
+  o.cancelButton->hide();
+  
   o.searchLine->installEventFilter( this );
   o.list->installEventFilter( this );
   o.list->setFocusPolicy(Qt::NoFocus);
@@ -244,10 +262,13 @@ QuickOpenWidgetHandler::QuickOpenWidgetHandler( QString title, QuickOpenModel* m
   o.itemsButton->setFocusPolicy(Qt::NoFocus);
 
   connect( o.searchLine, SIGNAL(textChanged( const QString& )), this, SLOT(textChanged( const QString& )) );
-  connect( m_dialog, SIGNAL(accepted()), this, SLOT(accept()) );
 
   connect( o.list, SIGNAL(doubleClicked( const QModelIndex& )), this, SLOT(doubleClicked( const QModelIndex& )) );
 
+  connect(o.okButton, SIGNAL(clicked(bool)), this, SLOT(accept()));
+  connect(o.okButton, SIGNAL(clicked(bool)), SIGNAL(ready()));
+  connect(o.cancelButton, SIGNAL(clicked(bool)), SIGNAL(ready()));
+  
   updateProviders();
 
   m_model->restart();
@@ -255,11 +276,29 @@ QuickOpenWidgetHandler::QuickOpenWidgetHandler( QString title, QuickOpenModel* m
   o.list->setColumnWidth( 0, 20 );
 }
 
-void QuickOpenWidgetHandler::run() {
+
+void QuickOpenWidget::setAlternativeSearchField(QLineEdit* alterantiveSearchField)
+{
+    o.searchLine = alterantiveSearchField;
+    o.searchLine->installEventFilter( this );
+    connect( o.searchLine, SIGNAL(textChanged( const QString& )), this, SLOT(textChanged( const QString& )) );
+}
+
+
+void QuickOpenWidget::showSearchField(bool b)
+{
+    if(b){
+      o.searchLine->show();
+      o.searchLabel->show();
+    }else{
+      o.searchLine->hide();
+      o.searchLabel->hide();
+    }
+}
+
+void QuickOpenWidget::prepareShow()
+{
   o.list->setModel( 0 );
-  m_dialog->show();
-  //This is a workaround for a problem in KStyle where the scroll-mode is overwritten with ScrollPerPixel during show()
-  //Usually all this stuff should be done BEFORE show() is called
   o.list->setVerticalScrollMode(QAbstractItemView::ScrollPerItem);
   m_model->setTreeView( o.list );
   o.list->setModel( m_model );
@@ -272,18 +311,44 @@ void QuickOpenWidgetHandler::run() {
   connect( o.list->selectionModel(), SIGNAL(selectionChanged( const QItemSelection&, const QItemSelection& )), this, SLOT(currentChanged( const QItemSelection&, const QItemSelection& )) );
 }
 
-QuickOpenWidgetHandler::~QuickOpenWidgetHandler() {
-  //if( m_model->treeView() == o.list )
+void QuickOpenWidgetDialog::run() {
+  m_widget->prepareShow();
+  m_dialog->show();
+}
+
+QuickOpenWidget::~QuickOpenWidget() {
   m_model->setTreeView( 0 );
+}
+
+
+QuickOpenWidgetDialog::QuickOpenWidgetDialog(QString title, QuickOpenModel* model, const QStringList& initialItems, const QStringList& initialScopes, bool listOnly, bool noSearchField)
+{
+  m_widget = new QuickOpenWidget(title, model, initialItems, initialScopes, listOnly, noSearchField);
+  
+  //KDialog always sets the focus on the "OK" button, so we use QDialog
+  m_dialog = new QDialog( ICore::self()->uiController()->activeMainWindow() );
+  m_dialog->resize(QSize(800, 400));
+
+  m_dialog->setWindowTitle(title);
+  QVBoxLayout* layout = new QVBoxLayout(m_dialog);
+  layout->addWidget(m_widget);
+  m_widget->showStandardButtons(true);
+  connect(m_widget, SIGNAL(ready()), m_dialog, SLOT(close()));
+  connect( m_dialog, SIGNAL(accepted()), m_widget, SLOT(accept()) );
+}
+
+
+QuickOpenWidgetDialog::~QuickOpenWidgetDialog()
+{
   delete m_dialog;
 }
 
-void QuickOpenWidgetHandler::setPreselectedText(const QString& text)
+void QuickOpenWidget::setPreselectedText(const QString& text)
 {
   m_preselectedText = text;
 }
 
-void QuickOpenWidgetHandler::updateProviders() {
+void QuickOpenWidget::updateProviders() {
   if(QAction* action = qobject_cast<QAction*>(sender())) {
     QMenu* menu = qobject_cast<QMenu*>(action->parentWidget());
     if(menu) {
@@ -321,12 +386,13 @@ void QuickOpenWidgetHandler::updateProviders() {
     o.scopesButton->setText(checkedScopes.join(", "));
   }
 
+  emit itemsChanged( checkedItems );
   emit scopesChanged( checkedScopes );
   m_model->enableProviders( checkedItems, checkedScopes );
 }
 
 
-void QuickOpenWidgetHandler::textChanged( const QString& str ) {
+void QuickOpenWidget::textChanged( const QString& str ) {
   m_model->textChanged( str );
 
   QModelIndex currentIndex = m_model->index(0, 0, QModelIndex());
@@ -335,7 +401,7 @@ void QuickOpenWidgetHandler::textChanged( const QString& str ) {
   callRowSelected();
 }
 
-void QuickOpenWidgetHandler::callRowSelected() {
+void QuickOpenWidget::callRowSelected() {
   QModelIndex currentIndex = o.list->selectionModel()->currentIndex();
   if( currentIndex.isValid() )
     m_model->rowSelected( currentIndex );
@@ -343,29 +409,29 @@ void QuickOpenWidgetHandler::callRowSelected() {
     kDebug() << "current index is not valid";
 }
 
-void QuickOpenWidgetHandler::currentChanged( const QModelIndex& /*current*/, const QModelIndex& /*previous */) {
+void QuickOpenWidget::currentChanged( const QModelIndex& /*current*/, const QModelIndex& /*previous */) {
   callRowSelected();
 }
 
-void QuickOpenWidgetHandler::currentChanged( const QItemSelection& /*current*/, const QItemSelection& /*previous */) {
+void QuickOpenWidget::currentChanged( const QItemSelection& /*current*/, const QItemSelection& /*previous */) {
   callRowSelected();
 }
 
-void QuickOpenWidgetHandler::accept() {
+void QuickOpenWidget::accept() {
   QString filterText = o.searchLine->text();
   m_model->execute( o.list->currentIndex(), filterText );
 }
 
-void QuickOpenWidgetHandler::doubleClicked ( const QModelIndex & index ) {
+void QuickOpenWidget::doubleClicked ( const QModelIndex & index ) {
   QString filterText = o.searchLine->text();
   if(  m_model->execute( index, filterText ) )
-    m_dialog->close();
+    emit ready();
   else if( filterText != o.searchLine->text() )
     o.searchLine->setText( filterText );
 }
 
 
-bool QuickOpenWidgetHandler::eventFilter ( QObject * watched, QEvent * event )
+bool QuickOpenWidget::eventFilter ( QObject * watched, QEvent * event )
 {
   QKeyEvent *keyEvent = dynamic_cast<QKeyEvent*>(event);
   
@@ -484,7 +550,8 @@ bool QuickOpenWidgetHandler::eventFilter ( QObject * watched, QEvent * event )
         } else {
           QString filterText = o.searchLine->text();
           if( m_model->execute( o.list->currentIndex(), filterText ) ) {
-            m_dialog->close();
+            if(!(keyEvent->modifiers() & Qt::ShiftModifier))
+              emit ready();
           } else {
             //Maybe the filter-text was changed:
             if( filterText != o.searchLine->text() ) {
@@ -500,10 +567,31 @@ bool QuickOpenWidgetHandler::eventFilter ( QObject * watched, QEvent * event )
   return false;
 }
 
+
+QuickOpenLineEdit* QuickOpenPlugin::quickOpenLine()
+{
+  QList< QuickOpenLineEdit* > lines = ICore::self()->uiController()->activeMainWindow()->findChildren<QuickOpenLineEdit*>("Quickopen");
+  foreach(QuickOpenLineEdit* line, lines) {
+    if(line->isVisible()) {
+      return line;
+    }
+  }
+  
+  return 0;
+}
+
+static QuickOpenPlugin* staticQuickOpenPlugin = 0;
+
+QuickOpenPlugin* QuickOpenPlugin::self()
+{
+  return staticQuickOpenPlugin;
+}
+
 QuickOpenPlugin::QuickOpenPlugin(QObject *parent,
                                  const QVariantList&)
     : KDevelop::IPlugin(KDevQuickOpenFactory::componentData(), parent)
 {
+    staticQuickOpenPlugin = this;
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IQuickOpen )
     setXMLFile( "kdevquickopen.rc" );
     m_model = new QuickOpenModel( 0 );
@@ -540,6 +628,11 @@ QuickOpenPlugin::QuickOpenPlugin(QObject *parent,
     quickOpenDefinition->setShortcut( Qt::CTRL | Qt::Key_Comma );
     connect(quickOpenDefinition, SIGNAL(triggered(bool)), this, SLOT(quickOpenDefinition()));
 
+    KAction* quickOpenLine = actions->addAction("quick_open_line");
+    quickOpenLine->setText( i18n("Embedded Quick Open") );
+//     quickOpenLine->setShortcut( Qt::CTRL | Qt::ALT | Qt::Key_E );
+//     connect(quickOpenLine, SIGNAL(triggered(bool)), this, SLOT(quickOpenLine(bool)));
+    quickOpenLine->setDefaultWidget(createQuickOpenLineWidget());
 //     KAction* quickOpenNavigate = actions->addAction("quick_open_navigate");
 //     quickOpenNavigate->setText( i18n("Navigate Declaration") );
 //     quickOpenNavigate->setShortcut( Qt::ALT | Qt::Key_Space );
@@ -551,6 +644,7 @@ QuickOpenPlugin::QuickOpenPlugin(QObject *parent,
     connect(quickOpenNavigateFunctions, SIGNAL(triggered(bool)), this, SLOT(quickOpenNavigateFunctions()));
     KConfigGroup quickopengrp = KGlobal::config()->group("QuickOpen");
     lastUsedScopes = quickopengrp.readEntry("SelectedScopes", QStringList() << i18n("Project") << i18n("Includes") << i18n("Includers") << i18n("Currently Open") );
+    lastUsedItems = quickopengrp.readEntry("SelectedItems", QStringList() );
 
     {
       m_openFilesData = new OpenFilesDataProvider();
@@ -610,19 +704,27 @@ void QuickOpenPlugin::showQuickOpen( ModelTypes modes )
   if((modes & OpenFiles) && !useScopes.contains(i18n("Currently Open")))
     useScopes << i18n("Currently Open");
 
-  m_currentWidgetHandler = new QuickOpenWidgetHandler( i18n("Quick Open"), m_model, initialItems, useScopes );
+  QuickOpenWidgetDialog* dialog = new QuickOpenWidgetDialog( i18n("Quick Open"), m_model, initialItems, useScopes );
+  m_currentWidgetHandler = dialog;
   if (!(modes & Files) || modes == QuickOpenPlugin::All)
   {
     KDevelop::IDocument *currentDoc = core()->documentController()->activeDocument();
     if (currentDoc && currentDoc->isTextDocument())
     {
       QString preselected = currentDoc->textSelection().isEmpty() ? currentDoc->textWord() : currentDoc->textDocument()->text(currentDoc->textSelection());
-      m_currentWidgetHandler->setPreselectedText(preselected);
+      dialog->widget()->setPreselectedText(preselected);
     }
   }
   
   connect( m_currentWidgetHandler, SIGNAL( scopesChanged( const QStringList& ) ), this, SLOT( storeScopes( const QStringList& ) ) );
-  m_currentWidgetHandler->run();
+  connect( m_currentWidgetHandler, SIGNAL( itemsChanged( const QStringList& ) ), this, SLOT( storeItems( const QStringList& ) ) );
+  
+  if(quickOpenLine()) {
+    quickOpenLine()->showWithWidget(dialog->widget());
+    dialog->deleteLater();
+  }else{
+    dialog->run();
+  }
 }
 
 
@@ -633,6 +735,13 @@ void QuickOpenPlugin::storeScopes( const QStringList& scopes )
   grp.writeEntry( "SelectedScopes", scopes );
 }
 
+void QuickOpenPlugin::storeItems( const QStringList& items )
+{
+  lastUsedItems = items;
+  KConfigGroup grp = KGlobal::config()->group("QuickOpen");
+  grp.writeEntry( "SelectedItems", items );
+}
+
 void QuickOpenPlugin::quickOpen()
 {
   showQuickOpen( All );
@@ -828,11 +937,12 @@ void QuickOpenPlugin::quickOpenNavigate()
     }
 
     //Change the parent so there are no conflicts in destruction order
-    m_currentWidgetHandler = new QuickOpenWidgetHandler( i18n("Navigate"), model, QStringList(), QStringList(), true, true );
+    QuickOpenWidgetDialog* dialog = new QuickOpenWidgetDialog( i18n("Navigate"), model, QStringList(), QStringList(), true, true );
+    m_currentWidgetHandler = dialog;
     model->setParent(m_currentWidgetHandler);
     model->setExpanded(model->index(0,0, QModelIndex()), true);
 
-    m_currentWidgetHandler->run();
+    dialog->run();
   }
 
   if(!decl) {
@@ -912,23 +1022,194 @@ void QuickOpenPlugin::quickOpenNavigateFunctions()
 
   model->registerProvider( QStringList(), QStringList(), new DeclarationListDataProvider(this, items, true) );
 
-  m_currentWidgetHandler = new QuickOpenWidgetHandler( i18n("Outline"), model, QStringList(), QStringList(), true );
+  QuickOpenWidgetDialog* dialog = new QuickOpenWidgetDialog( i18n("Outline"), model, QStringList(), QStringList(), true );
+  m_currentWidgetHandler = dialog;
   
-  model->setParent(m_currentWidgetHandler);
-  m_currentWidgetHandler->run();
+  model->setParent(dialog->widget());
+  
+  if(quickOpenLine()) {
+    quickOpenLine()->showWithWidget(dialog->widget());
+    dialog->deleteLater();
+  }else
+    dialog->run();
 
   //Select the declaration that contains the cursor
   if(cursorDecl) {
     int num = 0;
     foreach(const DUChainItem& item, items) {
       if(item.m_item.data() == cursorDecl) {
-        m_currentWidgetHandler->o.list->setCurrentIndex( model->index(num,0,QModelIndex()) );
-        m_currentWidgetHandler->o.list->scrollTo( model->index(num,0,QModelIndex()), QAbstractItemView::PositionAtCenter );
+        dialog->widget()->o.list->setCurrentIndex( model->index(num,0,QModelIndex()) );
+        dialog->widget()->o.list->scrollTo( model->index(num,0,QModelIndex()), QAbstractItemView::PositionAtCenter );
       }
       ++num;
     }
   }
 }
+QuickOpenLineEdit::QuickOpenLineEdit() : m_widget(0), m_forceUpdate(false) {
+    setMinimumWidth(200);
+    setMaximumWidth(400);
+    deactivate();
+    setObjectName("Quickopen");
+}
+QuickOpenLineEdit::~QuickOpenLineEdit() {
+    delete m_widget;
+}
+void QuickOpenLineEdit::keyPressEvent(QKeyEvent* ev) {
+    if (ev->key() == Qt::Key_Escape) {
+      kDebug() << "escape";
+        deactivate();
+        ev->accept();
+    }
+    QLineEdit::keyPressEvent(ev);
+}
+bool QuickOpenLineEdit::insideThis(QObject* object) {
+    while (object)
+    {
+        kDebug() << object;
+        if (object == this || object == m_widget)
+        {
+            return true;
+        }
+        object = object->parent();
+    }
+    return false;
+}
+
+void QuickOpenLineEdit::showWithWidget(QuickOpenWidget* widget)
+{
+  kDebug() << "storing widget" << widget;
+  deactivate();
+  if(m_widget) {
+    kDebug() << "deleting" << m_widget;
+    delete m_widget;
+  }
+  m_widget = widget;
+  m_forceUpdate = true;
+  setFocus();
+}
+
+void QuickOpenLineEdit::focusInEvent(QFocusEvent* ev) {
+    QLineEdit::focusInEvent(ev);
+//       delete m_widget;
+    kDebug() << "got focus";
+    kDebug() << "old widget" << m_widget << "force update:" << m_forceUpdate;
+    if (m_widget && !m_forceUpdate)
+        return;
+
+    if (!m_forceUpdate && !QuickOpenPlugin::self()->freeModel())
+        return;
+    
+    activate();
+    m_forceUpdate = false;
+    
+    if(!m_widget) {
+      m_widget = new QuickOpenWidget( i18n("Quick Open"), QuickOpenPlugin::self()->m_model, QuickOpenPlugin::self()->lastUsedItems, QuickOpenPlugin::self()->lastUsedScopes, false, true );
+    }else{
+      m_widget->showStandardButtons(false);
+      m_widget->showSearchField(false);
+    }
+    
+    m_widget->setParent(0, Qt::ToolTip);
+    m_widget->setFocusPolicy(Qt::NoFocus);
+    m_widget->setFrameStyle(QFrame::Raised | QFrame::StyledPanel);
+    m_widget->setLineWidth(5);
+    m_widget->setAlternativeSearchField(this);
+    
+    QuickOpenPlugin::self()->m_currentWidgetHandler = m_widget;
+    connect(m_widget, SIGNAL(ready()), SLOT(deactivate()));
+
+    connect( m_widget, SIGNAL( scopesChanged( const QStringList& ) ), QuickOpenPlugin::self(), SLOT( storeScopes( const QStringList& ) ) );
+    Q_ASSERT(m_widget->o.searchLine == this);
+    m_widget->prepareShow();
+    QRect widgetGeometry = QRect(mapToGlobal(QPoint(0, height())), mapToGlobal(QPoint(width(), height() + 400)));
+    widgetGeometry.setWidth(700); ///@todo Waste less space
+    QRect screenGeom = QApplication::desktop()->screenGeometry(this);
+    if (widgetGeometry.right() > screenGeom.right())
+        widgetGeometry.moveRight(screenGeom.right());
+    m_widget->setGeometry(widgetGeometry);
+
+    //Hack so we don't have a frame it top, where the widget docks to the line
+    QRect frameRect = m_widget->frameRect();
+    frameRect.setTop(frameRect.top()-10);
+    m_widget->setFrameRect(frameRect);
+
+    m_widget->show();
+}
+
+void QuickOpenLineEdit::hideEvent(QHideEvent* ev)
+{
+    QWidget::hideEvent(ev);
+    if(m_widget)
+      QMetaObject::invokeMethod(this, "checkFocus", Qt::QueuedConnection);
+//       deactivate();
+}
+
+bool QuickOpenLineEdit::eventFilter(QObject* obj, QEvent* e) {
+    if (!m_widget)
+        return false;
+    switch (e->type()) {
+     case QEvent::WindowActivate:
+    case QEvent::WindowDeactivate:
+        kDebug() << "closing because of window activation";
+        deactivate();
+    break;
+    case QEvent::FocusIn:
+        if (dynamic_cast<QWidget*>(obj)) {
+            QFocusEvent* focusEvent = dynamic_cast<QFocusEvent*>(e);
+            Q_ASSERT(focusEvent);
+            //Eat the focus event, keep the focus
+            kDebug() << "focus change" << "inside this: " << insideThis(obj) << "this" << this << "obj" << obj;
+            if(obj == this)
+              return false;
+            
+            kDebug() << "reason" << focusEvent->reason();
+            if (focusEvent->reason() != Qt::MouseFocusReason && focusEvent->reason() != Qt::ActiveWindowFocusReason) {
+                QMetaObject::invokeMethod(this, "checkFocus", Qt::QueuedConnection);
+                return false;
+            }
+            if (!insideThis(obj))
+                deactivate();
+        }
+        break;
+    default:
+        break;
+    }
+    return false;
+}
+void QuickOpenLineEdit::activate() {
+    kDebug() << "activating";
+    setText("");
+    setStyleSheet("");
+    qApp->installEventFilter(this);
+}
+void QuickOpenLineEdit::deactivate() {
+    kDebug() << "deactivating";
+    
+    setText(i18n("Quick Open"));
+    setStyleSheet("color: grey"); ///@todo Better color picking
+    if (m_widget) {
+        m_widget->deleteLater();
+        QMetaObject::invokeMethod(this, "checkFocus", Qt::QueuedConnection);
+    }
+    m_widget = 0;
+    qApp->removeEventFilter(this);
+    
+}
+
+void QuickOpenLineEdit::checkFocus()
+{
+    kDebug() << "checking focus" << m_widget;
+    if(m_widget) {
+      if(isVisible() && !isHidden())
+        setFocus();
+      else
+        deactivate();
+    }else{
+       if (ICore::self()->documentController()->activeDocument())
+           ICore::self()->documentController()->activateDocument(ICore::self()->documentController()->activeDocument());
+    }
+}
+
 
 #include "quickopenplugin.moc"
 
