@@ -45,7 +45,7 @@ void SvnInternalAddJob::run()
     {
         try
         {
-            QByteArray ba = url.path( KUrl::RemoveTrailingSlash ).toUtf8();
+            QByteArray ba = url.toLocalFile( KUrl::RemoveTrailingSlash ).toUtf8();
             cli.add( svn::Path( ba.data() ), recursive() );
         }catch( svn::ClientException ce )
         {
@@ -86,6 +86,7 @@ SvnAddJob::SvnAddJob( KDevSvnPlugin* parent )
 {
     setType( KDevelop::VcsJob::Add );
     m_job = new SvnInternalAddJob( this );
+    setObjectName(i18n("Subversion Add"));
 }
 
 QVariant SvnAddJob::fetchResults()
