@@ -46,7 +46,7 @@ void SvnInternalRevertJob::run()
     KUrl::List l = locations();
     foreach( const KUrl &url, l )
     {
-        QByteArray ba = url.path( KUrl::RemoveTrailingSlash ).toUtf8();
+        QByteArray ba = url.toLocalFile( KUrl::RemoveTrailingSlash ).toUtf8();
         targets.push_back( svn::Path( ba.data() ) );
     }
     try
@@ -90,6 +90,7 @@ SvnRevertJob::SvnRevertJob( KDevSvnPlugin* parent )
 {
     setType( KDevelop::VcsJob::Add );
     m_job = new SvnInternalRevertJob( this );
+    setObjectName(i18n("Subversion Revert"));
 }
 
 QVariant SvnRevertJob::fetchResults()
