@@ -50,6 +50,7 @@
 #include "selectioncontroller.h"
 #include "debugcontroller.h"
 #include "kdevplatformversion.h"
+#include "workingsetcontroller.h"
 
 namespace KDevelop {
 
@@ -89,6 +90,10 @@ void CorePrivate::initialize(Core::Setup mode)
     {
         sessionController = new SessionController(m_core);
     }
+    if( !workingSetController )
+    {
+        workingSetController = new WorkingSetController(m_core);
+    }
     kDebug() << "Creating ui controller";
     if( !uiController )
     {
@@ -163,6 +168,7 @@ void CorePrivate::initialize(Core::Setup mode)
 
     kDebug() << "loading session plugins";
     pluginController->initialize();
+    workingSetController->initialize();
 
     if(!(mode & Core::NoUi))
     {
@@ -192,6 +198,7 @@ CorePrivate::~CorePrivate()
     delete sourceFormatterController;
     delete documentationController;
     delete debugController;
+    delete workingSetController;
 }
 
 
@@ -238,6 +245,7 @@ void Core::cleanup()
         d->selectionController->cleanup();
         // Save the layout of the ui here, so run it first
         d->uiController->cleanup();
+        d->workingSetController->cleanup();
 
         /* Must be called before projectController->cleanup(). */
         // Closes all documents (discards, as already saved if the user wished earlier)
@@ -363,6 +371,12 @@ DebugController* Core::debugControllerInternal()
     return d->debugController;
 }
 
+
+WorkingSetController* Core::workingSetControllerInternal()
+{
+    return d->workingSetController;
+}
+
 QString Core::version()
 {
     return KDEVPLATFORM_VERSION_STR;
