@@ -125,7 +125,7 @@ DebugController::DebugController(QObject *parent)
 
 void DebugController::initialize()
 {
-    stateChanged("stopped");
+    stateChanged("ended");
 }
 
 BreakpointModel* DebugController::breakpointModel()
@@ -320,6 +320,13 @@ void DebugController::debuggerStateChanged(KDevelop::IDebugSession::DebuggerStat
     if (session == m_currentSession) {
         updateDebuggerState(state, session);
     }
+
+    if (state == IDebugSession::EndedState) {
+        session->deleteLater();
+        if (session == m_currentSession) {
+            m_currentSession = 0;
+        }
+    }
 }
 
 void DebugController::updateDebuggerState(IDebugSession::DebuggerState state, IDebugSession *session)
@@ -331,8 +338,7 @@ void DebugController::updateDebuggerState(IDebugSession::DebuggerState state, ID
         case IDebugSession::StoppingState:
             kDebug() << "new state: stopped";
             stateChanged("stopped");
-            clearExecutionPoint();
-            m_restartDebugger->setEnabled(false);
+            m_restartDebugger->setEnabled(session->restartAvaliable());
             break;
         case IDebugSession::StartingState:
         case IDebugSession::PausedState:
@@ -344,12 +350,14 @@ void DebugController::updateDebuggerState(IDebugSession::DebuggerState state, ID
             kDebug() << "new state: active";
             stateChanged("active");
             m_restartDebugger->setEnabled(false);
+            clearExecutionPoint();
+            break;
+        case IDebugSession::EndedState:
+            kDebug() << "new state: ended";
+            stateChanged("ended");
+            clearExecutionPoint();
+            m_restartDebugger->setEnabled(false);
             break;
-    }
-
-    if (state == IDebugSession::StoppedState || state == IDebugSession::NotStartedState
-       || state == IDebugSession::StoppingState || state == IDebugSession::ActiveState) {
-        clearExecutionPoint();
     }
 }
 
