@@ -55,27 +55,13 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
     setButtonFocus( KDialog::Ok );
     button( KDialog::Apply )->setEnabled( false );
     
-    QSplitter* split = new QSplitter();
+    setupUi( mainWidget() );
     
-    QWidget* leftWidget = new QWidget( split );
-    QGridLayout* lay = new QGridLayout( leftWidget );
-    leftWidget->setLayout( lay );
-    
-    addConfig = new QToolButton( leftWidget );
     addConfig->setIcon( KIcon("list-add") );
-    addConfig->setText( i18n( "Add" ) );
     addConfig->setEnabled( false );
-    deleteConfig = new QToolButton( leftWidget );
     deleteConfig->setIcon( KIcon("list-remove") );
-    deleteConfig->setText( i18n( "Delete" ) );
     deleteConfig->setEnabled( false );
     
-    lay->addWidget( addConfig , 0, 0);
-    lay->addWidget( deleteConfig, 0, 1 );
-    lay->setColumnStretch( 2, 1 );
-    
-    tree = new QTreeView( leftWidget );
-    lay->addWidget( tree, 2, 0, 1, 3  );
     model = new LaunchConfigurationsModel( tree );
     tree->setModel( model );
     tree->setIndentation( 5 );
@@ -89,20 +75,6 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
     dlg->itemEditorFactory()->registerEditor( QVariant::String, new LaunchConfigurationTypeEditorCreator() );
     tree->setItemDelegateForColumn( 1, dlg );
     
-    split->addWidget( leftWidget );
-    
-    stack = new QStackedWidget( split );
-    
-    // setup a default widget to make sure the treeview is sized properly on start
-    QWidget* topWidget = new QWidget( stack );
-    topWidget->setMinimumWidth( 120 );
-    stack->addWidget(topWidget);
-    stack->setCurrentIndex( 0 );
-    split->addWidget( stack );
-    split->setSizes( QList<int>() << 2 << 5 );
-    
-    setMainWidget( split );
-    
     connect( addConfig, SIGNAL(clicked()), this, SLOT(createConfiguration()));
     connect( deleteConfig, SIGNAL(clicked()), this, SLOT(deleteConfiguration()));
     
@@ -127,7 +99,7 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
     tree->selectionModel()->select( QItemSelection( idx, idx ), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
     tree->selectionModel()->setCurrentIndex( idx, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
     tree->resizeColumnToContents( 0 );
-    setInitialSize( QSize( 750, 550 ) );
+    setInitialSize( QSize( 700, 500 ) );
     
     connect( this, SIGNAL(okClicked()), SLOT(saveConfig()) );
     connect( this, SIGNAL(applyClicked()), SLOT(saveConfig()) );
@@ -140,6 +112,7 @@ void LaunchConfigurationDialog::selectedConfig(QItemSelection selected, QItemSel
         LaunchConfiguration* l = model->configForIndex( deselected.indexes().first() );
         if( l )
         {
+            disconnect(l, SIGNAL(nameChanged(QString)), this,  SLOT(updateNameLabel(QString)));
             if( KMessageBox::questionYesNo( this, i18n("Selected Launch Configuration has unsaved changes. Do you want to save it?"), i18n("Unsaved Changes") ) == KMessageBox::Yes )
             {
                 saveConfig( deselected.indexes().first() );
@@ -150,6 +123,7 @@ void LaunchConfigurationDialog::selectedConfig(QItemSelection selected, QItemSel
             }
         }
     }
+    updateNameLabel("");
     if( !selected.indexes().isEmpty() )
     {
         LaunchConfiguration* l = model->configForIndex( selected.indexes().first() );
@@ -168,6 +142,8 @@ void LaunchConfigurationDialog::selectedConfig(QItemSelection selected, QItemSel
                 stack->addWidget( tab );
             }
             tab->setLaunchConfiguration( l );
+            updateNameLabel( l->name() );
+            connect( l, SIGNAL(nameChanged(QString)), SLOT(updateNameLabel(QString)) );
             stack->setCurrentWidget( tab );
             
             addConfig->setEnabled( true );
@@ -222,6 +198,13 @@ void LaunchConfigurationDialog::deleteConfiguration()
     }
 }
 
+
+void LaunchConfigurationDialog::updateNameLabel( const QString& name )
+{
+    configName->setText( i18n("<b>%1</b>", name ) );
+}
+
+
 void LaunchConfigurationDialog::createConfiguration()
 {
     if( !tree->selectionModel()->selectedRows().isEmpty() )
@@ -263,8 +246,8 @@ LaunchConfigurationsModel::LaunchConfigurationsModel(QObject* parent): QAbstract
             parent = topItems.at(0);
         }
         t->parent = parent;
-        t->row = parent->childs.count();
-        parent->childs.append( t );
+        t->row = parent->children.count();
+        parent->children.append( t );
     }    
 }
 
@@ -356,7 +339,7 @@ QModelIndex LaunchConfigurationsModel::index(int row, int column, const QModelIn
     } else 
     {
         TreeItem* t = static_cast<TreeItem*>( parent.internalPointer() );
-        tree = t->childs.at( row );
+        tree = t->children.at( row );
     }
     if( tree )
     {
@@ -385,7 +368,7 @@ int LaunchConfigurationsModel::rowCount(const QModelIndex& parent) const
     if( parent.isValid() )
     {
         TreeItem* t = static_cast<TreeItem*>( parent.internalPointer() );
-        return t->childs.count();
+        return t->children.count();
     } else
     {
         return topItems.count();
@@ -476,7 +459,7 @@ QModelIndex LaunchConfigurationsModel::indexForConfig( LaunchConfiguration* l )
         
         if( tparent )
         {
-            foreach( TreeItem* c, tparent->childs )
+            foreach( TreeItem* c, tparent->children )
             {
                 if( c->launch && c->launch == l )
                 {
@@ -493,7 +476,7 @@ void LaunchConfigurationsModel::deleteConfiguration( const QModelIndex& index )
 {
     TreeItem* t = static_cast<TreeItem*>( index.internalPointer() );
     beginRemoveRows( parent( index ), index.row(), index.row() );
-    t->parent->childs.removeAll( t );
+    t->parent->children.removeAll( t );
     Core::self()->runControllerInternal()->removeLaunchConfiguration( t->launch );
     endRemoveRows();
 }
@@ -536,8 +519,8 @@ void LaunchConfigurationsModel::createConfiguration(const QModelIndex& parent )
         TreeItem* item = new TreeItem;
         item->launch = l;
         item->parent = t;
-        item->row = t->childs.count();
-        t->childs.append( item );
+        item->row = t->children.count();
+        t->children.append( item );
         endInsertRows();
     }
 }
@@ -631,6 +614,7 @@ void LaunchConfigTypePage::changeLauncher( int idx )
         ui->tab->removePage( p );
         delete p;
     }
+    launcherPages.clear();
     ILauncher* l = config->type()->launcherForId( ui->launcher->itemData( idx ).toString() );
     if( l )
     {
@@ -641,6 +625,7 @@ void LaunchConfigTypePage::changeLauncher( int idx )
             connect( page, SIGNAL(changed()), SIGNAL(changed()) );
             ui->tab->addTab( page, page->icon(), page->title() );
             page->loadFromConfiguration( config->config() );
+            launcherPages << page;
         }
     }
     
