@@ -44,13 +44,22 @@ Boston, MA 02110-1301, USA.
 #include "uicontroller.h"
 #include "documentcontroller.h"
 #include "debugcontroller.h"
+#include "workingsetcontroller.h"
 
 namespace KDevelop
 {
 
+
+QWidget* MainWindow::customButtonForAreaSwitcher ( Sublime::Area* area )
+{
+    return Core::self()->workingSetControllerInternal()->createSetManagerWidget(this, true, area);
+}
+
 MainWindow::MainWindow( Sublime::Controller *parent, Qt::WFlags flags )
         : Sublime::MainWindow( parent, flags )
 {
+    setAreaSwitcherCornerWidget(Core::self()->workingSetControllerInternal()->createSetManagerWidget(this));
+    
     KConfigGroup cg = KGlobal::config()->group( "UiSettings" );
     int bottomleft = cg.readEntry( "BottomLeftCornerOwner", 0 );
     int bottomright = cg.readEntry( "BottomRightCornerOwner", 0 );
@@ -118,6 +127,7 @@ void MainWindow::loadSettings()
         setCorner( Qt::BottomRightCorner, Qt::BottomDockWidgetArea );
 
     d->setupAreaSelectorActions();
+    setupAreaSelector();
 
     Sublime::MainWindow::loadSettings();
 }
@@ -192,6 +202,13 @@ void MainWindow::initializeStatusBar()
     d->setupStatusBar();
 }
 
+
+void MainWindow::setupAreaSelector()
+{
+    Sublime::MainWindow::setupAreaSelector();
+    d->setupAreaSelector();
+}
+
 }
 
 #include "mainwindow.moc"
