@@ -52,6 +52,8 @@ public:
     /*! @p status must implement KDevelop::IStatus */
     void registerStatus(QObject* status);
 
+    virtual QWidget* customButtonForAreaSwitcher( Sublime::Area* area );
+    
 public Q_SLOTS:
     virtual void setVisible( bool visible );
 
@@ -62,7 +64,8 @@ Q_SIGNALS:
 protected:
     //FIXME DOCUMENT!!!  queryClose() must call all of the Core cleanup() methods!
     virtual bool queryClose();
-
+    virtual void setupAreaSelector();
+    
 public Q_SLOTS:
     virtual void loadSettings();
     virtual void saveSettings();
