@@ -57,6 +57,7 @@ Boston, MA 02110-1301, USA.
 #include "statusbar.h"
 
 #include "mainwindow.h"
+#include "workingsetcontroller.h"
 
 namespace KDevelop {
 
@@ -145,6 +146,7 @@ void MainWindowPrivate::changeActiveView(Sublime::View *view)
     // If the new view is KXMLGUIClient, add it.
     if (KXMLGUIClient* c = dynamic_cast<KXMLGUIClient*>(viewWidget))
     {
+        kDebug() << "setting new XMLGUI client" << viewWidget;
         lastXMLGUIClientView = viewWidget;
         m_mainWindow->guiFactory()->addClient(c);
         connect(viewWidget, SIGNAL(destroyed(QObject*)),
@@ -164,6 +166,7 @@ void MainWindowPrivate::xmlguiclientDestroyed(QObject* obj)
        is undefined behaviour.  We hope to catch view deletion a bit
        later, but if we fail, we better report it now, rather than
        get a weird crash a bit later.  */
+       Q_ASSERT(obj == lastXMLGUIClientView);
        Q_ASSERT(false && "xmlgui clients management is messed up");
 }
 
@@ -308,6 +311,14 @@ void MainWindowPrivate::setupAreaSelectorActions()
     m_mainWindow->plugActionList("area_selector", areaActions);
 }
 
+void MainWindowPrivate::setupAreaSelector()
+{
+    if(!m_workingSetCornerWidget) {
+        m_workingSetCornerWidget = Core::self()->workingSetControllerInternal()->createSetManagerWidget(m_mainWindow, true);
+        m_mainWindow->setTabBarLeftCornerWidget(m_workingSetCornerWidget);
+    }
+}
+
 void MainWindowPrivate::toggleArea(bool b)
 {
     if (!b) return;
