@@ -55,6 +55,7 @@ public:
     virtual KTextEditor::Document* textDocument() const;
     virtual bool save(DocumentSaveMode mode = Default);
     virtual void reload();
+    ///Closes and deletes the document. Asks the user before if needed.
     virtual bool close(DocumentSaveMode mode = Default);
     virtual bool isActive() const;
     virtual DocumentState state() const;
@@ -66,7 +67,7 @@ public:
     virtual void setTextSelection(const KTextEditor::Range &range);
 
     //Overridden from Sublime::Document
-    virtual void closeDocument();
+    virtual bool closeDocument();
     
 private:
     class PartDocumentPrivate * const d;
