@@ -101,6 +101,12 @@ public:
     bool canUnload( const KPluginInfo& plugin )
     {
         QStringList interfaces=plugin.property( "X-KDevelop-Interfaces" ).toStringList();
+        if(interfaces.contains("ILanguageSupport")) {
+            // Language supports can not be unloaded currently, mainly due to LanguageController and associated languages/mimetypes
+            // See: https://bugs.kde.org/show_bug.cgi?id=194337
+            return false; 
+        }
+        
         foreach( const KPluginInfo& info, loadedPlugins.keys() )
         {
             if( info.pluginName() != plugin.pluginName() ) 
@@ -161,8 +167,8 @@ PluginController::~PluginController()
 
 KPluginInfo PluginController::pluginInfo( const IPlugin* plugin ) const
 {
-    for ( PluginControllerPrivate::InfoToPluginMap::ConstIterator it = d->loadedPlugins.begin();
-          it != d->loadedPlugins.end(); ++it )
+    for ( PluginControllerPrivate::InfoToPluginMap::ConstIterator it = d->loadedPlugins.constBegin();
+          it != d->loadedPlugins.constEnd(); ++it )
     {
         if ( it.value() == plugin )
             return it.key();
@@ -310,7 +316,7 @@ void PluginController::unloadPlugin(IPlugin* plugin, PluginDeletion deletion)
 KPluginInfo PluginController::infoForPluginId( const QString &pluginId ) const
 {
     QList<KPluginInfo>::ConstIterator it;
-    for ( it = d->plugins.begin(); it != d->plugins.end(); ++it )
+    for ( it = d->plugins.constBegin(); it != d->plugins.constEnd(); ++it )
     {
         if ( it->pluginName() == pluginId )
             return *it;
