@@ -85,7 +85,7 @@ bool reopenProjectsOnStartup()
 bool parseAllProjectSources()
 {
     KConfigGroup group = Core::self()->activeSession()->config()->group( "Project Manager" );
-    return group.readEntry( "Parse All Project Sources", false );
+    return group.readEntry( "Parse All Project Sources", true );
 }
 
 class ProjectControllerPrivate
@@ -149,6 +149,7 @@ public:
         }
         m_configuringProject = proj;
         m_cfgDlgs[proj]->exec();
+        proj->projectConfiguration()->sync();
         m_configuringProject = 0;
     }
     void saveListOfOpenedProjects()
@@ -238,12 +239,17 @@ ProjectDialogProvider::ProjectDialogProvider(ProjectControllerPrivate* const p)
 ProjectDialogProvider::~ProjectDialogProvider()
 {}
 
-void writeNewProjectFile( KSharedConfig::Ptr cfg, const QString& name, const QString& manager )
+bool writeNewProjectFile( KSharedConfig::Ptr cfg, const QString& name, const QString& manager )
 {
+    if (!cfg->isConfigWritable(true)) {
+        kDebug() << "can't write to configfile";
+        return false;
+    }
     KConfigGroup grp = cfg->group( "Project" );
     grp.writeEntry( "Name", name );
     grp.writeEntry( "Manager", manager );
     cfg->sync();
+    return true;
 }
 
 bool projectFileExists( const KUrl& u )
@@ -270,19 +276,29 @@ KUrl ProjectDialogProvider::askProjectConfigLocation(const KUrl& startUrl)
     {
         if( projectFileUrl.isLocalFile() )
         {
-            writeNewProjectFile( KSharedConfig::openConfig( projectFileUrl.toLocalFile(), KConfig::SimpleConfig ),
+            bool ok = writeNewProjectFile( KSharedConfig::openConfig( projectFileUrl.toLocalFile(), KConfig::SimpleConfig ),
                             dlg.projectName(),
                             dlg.projectManager() );
+            if (!ok)
+                return KUrl();
         } else
         {
             KTemporaryFile tmp;
             ///TODO: do we really want to set setAutoRemove to false??
             tmp.setAutoRemove( false );
             tmp.open();
-            writeNewProjectFile( KSharedConfig::openConfig( tmp.fileName(), KConfig::SimpleConfig ),
+            bool ok = writeNewProjectFile( KSharedConfig::openConfig( tmp.fileName(), KConfig::SimpleConfig ),
                             dlg.projectName(),
                             dlg.projectManager() );
-            KIO::NetAccess::upload( tmp.fileName(), projectFileUrl, Core::self()->uiControllerInternal()->defaultMainWindow() );
+            if (!ok)
+                return KUrl();
+
+            ok = KIO::NetAccess::upload( tmp.fileName(), projectFileUrl, Core::self()->uiControllerInternal()->defaultMainWindow() );
+            if (!ok) {
+                KMessageBox::error(d->m_core->uiControllerInternal()->defaultMainWindow(),
+                    i18n("Unable to create configuration file %1", projectFileUrl.url()));
+                return KUrl();
+            }
         }
     }
     return projectFileUrl;
@@ -327,10 +343,10 @@ void ProjectController::setupActions()
     KAction *action;
 
     action = ac->addAction( "project_open" );
-    action->setText(i18n( "&Open Project..." ) );
+    action->setText(i18n( "Open / Import Project..." ) );
     connect( action, SIGNAL( triggered( bool ) ), SLOT( openProject() ) );
-    action->setToolTip( i18n( "Open project" ) );
-    action->setWhatsThis( i18n( "<b>Open project</b><p>Opens a KDevelop 4 project.</p>" ) );
+    action->setToolTip( i18n( "Open / Import Oroject" ) );
+    action->setWhatsThis( i18n( "<b>Open / Import project</b><p>Open an existing KDevelop 4 project or import an existing Project into KDevelop 4. This entry allows to select a KDevelop4 project file or an existing directory to open it in KDevelop. When opening an existing directory that doesn't yet have a KDevelop4 project file the file will be created.</p>" ) );
     action->setIcon(KIcon("project-open"));
 
 //    action = ac->addAction( "project_close" );
@@ -787,6 +803,16 @@ KUrl ProjectController::projectsBaseDirectory() const
                                      KUrl( QDir::homePath()+"/projects" ) );
 }
 
+QString ProjectController::prettyFileName(KUrl url) const
+{
+    IProject* project = Core::self()->projectController()->findProjectForUrl(url);
+    QString prefixText = url.upUrl().pathOrUrl(KUrl::AddTrailingSlash);
+    if(project)
+        prefixText = "<i>" +  project->name() + "/</i>" + project->relativeUrl(url.upUrl()).path(KUrl::AddTrailingSlash);
+
+    return prefixText + "<b>" + url.fileName() + "</b>";
+    
+}
 
 }
 
