@@ -1,5 +1,5 @@
 /* This file is part of KDevelop
-Copyright 2008 Anreas Pakulat <apaku@gmx.de>
+Copyright 2008 Andreas Pakulat <apaku@gmx.de>
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
@@ -70,6 +70,7 @@ SessionController::SessionController( QObject *parent )
 
 SessionController::~SessionController()
 {
+    delete d;
 }
 
 void SessionController::cleanup()
@@ -117,19 +118,6 @@ QList<QString> SessionController::sessions() const
     return l;
 }
 
-QString getNewSessionDirName( const QString& sname )
-{
-    QDir sdir( SessionController::sessionDirectory() );
-    QString newname = sname;
-    int i = 0;
-    while( sdir.exists( newname ) ) 
-    {
-        newname = QString("%1_%2").arg( sname ).arg( i );
-        ++i;
-    }
-    return newname;
-}
-
 Session* SessionController::createSession( const QString& name )
 {
     Session* s = new Session( QUuid::createUuid() );
