@@ -22,16 +22,17 @@ Boston, MA 02110-1301, USA.
 
 #include <interfaces/isourceformattercontroller.h>
 
-#include <QHash>
-#include <QList>
-#include <KMimeType>
-#include <KConfigGroup>
+#include <QtCore/QHash>
+#include <QtCore/QList>
+#include <KDE/KMimeType>
+#include <KDE/KConfigGroup>
+#include <KDE/KPluginInfo>
 
 #include "shellexport.h"
 
 namespace KDevelop
 {
-        class ISourceFormatter;
+	class ISourceFormatter;
 	class IPlugin;
 
 typedef QHash<QString, QList<KDevelop::IPlugin*> > IPluginHash;
@@ -68,7 +69,7 @@ class KDEVPLATFORMSHELL_EXPORT SourceFormatterController : public ISourceFormatt
 		*/
 		bool isMimeTypeSupported(const KMimeType::Ptr &mime);
 
-		/** A ist of all languages (corresponding to a
+		/** A list of all languages (corresponding to a
 		* \ref KDevelop::ILanguageSupport) supported by loaded plugins.
 		*/
 		QStringList languages();
@@ -144,7 +145,7 @@ class KDEVPLATFORMSHELL_EXPORT SourceFormatterController : public ISourceFormatt
 		/** \return the language support plugin corresponding to
 		* a mime type name.
 		*/
-		KDevelop::IPlugin* languageSupportForMimeType(const QString &name);
+		KPluginInfo languageSupportForMimeType(const QString &name);
 		/** \return The name of the language corresponding to this mime type name.
 		*/
 		QString languageNameFromLanguageSupport(const QString &mime);
