@@ -49,6 +49,7 @@
 #include "assistantpopup.h"
 #include <kactioncollection.h>
 #include <ktexteditor/view.h>
+#include "workingsetcontroller.h"
 
 namespace KDevelop {
 
@@ -57,6 +58,8 @@ public:
     UiControllerPrivate(UiController *controller)
     : cfgDlg(0), areasRestored(false), m_controller(controller)
     {
+        Core::self()->workingSetControllerInternal()->initializeController(controller);
+        
         QMap<QString, Sublime::Position> desired;
 
         desired["org.kdevelop.ClassBrowserView"] = Sublime::Left;
@@ -67,6 +70,7 @@ public:
         desired["org.kdevelop.OutputView"] = Sublime::Bottom;
         desired["org.kdevelop.ContextBrowser"] = Sublime::Bottom;
         desired["org.kdevelop.debugger.ConsoleView"] = Sublime::Bottom;
+        desired["org.kdevelop.KonsoleView"] = Sublime::Bottom;
         Sublime::Area* a =
             new Sublime::Area(m_controller, "code", i18n("Code"));
         a->setDesiredToolViews(desired);
@@ -78,6 +82,7 @@ public:
         desired["org.kdevelop.debugger.BreakpointsView"] = Sublime::Bottom;
         desired["org.kdevelop.debugger.StackView"] = Sublime::Bottom;
         desired["org.kdevelop.debugger.ConsoleView"] = Sublime::Bottom;
+        desired["org.kdevelop.KonsoleView"] = Sublime::Bottom;
         a = new Sublime::Area(m_controller, "debug", i18n("Debug"));
         a->setDesiredToolViews(desired);
         a->setIconName("tools-report-bug");
@@ -363,8 +368,8 @@ void UiController::addNewToolView(MainWindow *mw)
     QListWidget *list = new QListWidget(dia);
 
     list->setSortingEnabled(true);
-    for (QMap<IToolViewFactory*, Sublime::ToolDocument*>::const_iterator it = d->factoryDocuments.begin();
-        it != d->factoryDocuments.end(); ++it)
+    for (QMap<IToolViewFactory*, Sublime::ToolDocument*>::const_iterator it = d->factoryDocuments.constBegin();
+        it != d->factoryDocuments.constEnd(); ++it)
     {
         ViewSelectorItem *item = new ViewSelectorItem(it.value()->title(), list);
         item->factory = it.key();
@@ -399,7 +404,7 @@ void UiController::showSettingsDialog()
 // the show() call doesn't show the dialog
 //     if( d->cfgDlg->dialog()->parentWidget() != activeMainWindow() )
 //         d->cfgDlg->dialog()->setParent( activeMainWindow() );
-    d->cfgDlg->show();
+    d->cfgDlg->exec();
 }
 
 Sublime::Controller* UiController::controller()
@@ -415,105 +420,14 @@ KParts::MainWindow *UiController::activeMainWindow()
 void UiController::saveArea(Sublime::Area * area, KConfigGroup & group)
 {
     area->save(group);
-    saveArea(area->rootIndex(), group);
-}
-
-void UiController::saveArea(Sublime::AreaIndex * area, KConfigGroup & group)
-{
-    if (area->isSplitted()) {
-        group.writeEntry("Orientation", area->orientation() == Qt::Horizontal ? "Horizontal" : "Vertical");
-
-        if (area->first()) {
-            KConfigGroup subgroup(&group, "0");
-            subgroup.deleteGroup();
-            saveArea(area->first(), subgroup);
-        }
-
-        if (area->second()) {
-            KConfigGroup subgroup(&group, "1");
-            subgroup.deleteGroup();
-            saveArea(area->second(), subgroup);
-        }
-    } else {
-        group.writeEntry("View Count", area->viewCount());
-
-        int index = 0;
-        foreach (Sublime::View* view, area->views()) {
-            group.writeEntry(QString("View %1 Type").arg(index), view->document()->documentType());
-            group.writeEntry(QString("View %1").arg(index), view->document()->documentSpecifier());
-            QString state = view->viewState();
-            if (!state.isEmpty())
-                group.writeEntry(QString("View %1 State").arg(index), state);
-
-            ++index;
-        }
-    }
+    Core::self()->workingSetControllerInternal()->getWorkingSet(area->workingSet())->saveFromArea(area, area->rootIndex());
 }
 
 void UiController::loadArea(Sublime::Area * area, const KConfigGroup & group)
 {
     area->load(group);
-    loadArea(area, area->rootIndex(), group);
-}
-
-void UiController::loadArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex, const KConfigGroup& group)
-{
-    if (group.hasKey("Orientation")) {
-        QStringList subgroups = group.groupList();
-
-        if (subgroups.contains("0")) {
-            if (!areaIndex->isSplitted())
-                areaIndex->split(group.readEntry("Orientation", "Horizontal") == "Vertical" ? Qt::Vertical : Qt::Horizontal);
-
-            KConfigGroup subgroup(&group, "0");
-            loadArea(area, areaIndex->first(), subgroup);
-
-            if (subgroups.contains("1")) {
-                Q_ASSERT(areaIndex->isSplitted());
-                KConfigGroup subgroup(&group, "1");
-                loadArea(area, areaIndex->second(), subgroup);
-            }
-        }
-
-    } else {
-        while (areaIndex->isSplitted()) {
-            areaIndex = areaIndex->first();
-            Q_ASSERT(areaIndex);// Split area index did not contain a first child area index if this fails
-        }
-
-        int viewCount = group.readEntry("View Count", 0);
-        for (int i = 0; i < viewCount; ++i) {
-            QString type = group.readEntry(QString("View %1 Type").arg(i), "");
-            QString specifier = group.readEntry(QString("View %1").arg(i), "");
-
-            bool viewExists = false;
-            foreach (Sublime::View* view, areaIndex->views()) {
-                if (view->document()->documentSpecifier() == specifier) {
-                    viewExists = true;
-                    break;
-                }
-            }
-
-            if (viewExists)
-                continue;
-
-
-            IDocument* doc = Core::self()->documentControllerInternal()->openDocument(specifier,
-                KTextEditor::Cursor::invalid(), IDocumentController::DoNotActivate | IDocumentController::DoNotCreateView);
-            Sublime::Document *document = dynamic_cast<Sublime::Document*>(doc);
-            if (document) {
-                Sublime::View* view = document->createView();
-
-                QString state = group.readEntry(QString("View %1 State").arg(i), "");
-                if (!state.isEmpty())
-                    view->setState(state);
-
-                area->addView(view, areaIndex);
-            } else {
-                kWarning() << "Unable to create view of type " << type;
-            }
-        }
-    }
+    WorkingSet* set = Core::self()->workingSetControllerInternal()->getWorkingSet(area->workingSet());
+    Q_ASSERT(set->isConnected(area));
 }
 
 void UiController::saveAllAreas(KSharedConfig::Ptr config)
@@ -561,8 +475,8 @@ void UiController::loadAllAreas(KSharedConfig::Ptr config)
     foreach (Sublime::Area *area, defaultAreas())
     {
         QMap<IToolViewFactory*, Sublime::ToolDocument*>::const_iterator i, e;
-        for (i = d->factoryDocuments.begin(),
-                 e = d->factoryDocuments.end(); i != e; ++i)
+        for (i = d->factoryDocuments.constBegin(),
+                 e = d->factoryDocuments.constEnd(); i != e; ++i)
         {
             addToolViewIfWanted(i.key(), i.value(), area);
         }
@@ -603,8 +517,8 @@ void UiController::loadAllAreas(KSharedConfig::Ptr config)
             // At this point we know which toolviews the area wants.
             // Tender all tool views we have.
             QMap<IToolViewFactory*, Sublime::ToolDocument*>::const_iterator i, e;
-            for (i = d->factoryDocuments.begin(),
-                     e = d->factoryDocuments.end(); i != e; ++i)
+            for (i = d->factoryDocuments.constBegin(),
+                     e = d->factoryDocuments.constEnd(); i != e; ++i)
             {
                 addToolViewIfWanted(i.key(), i.value(), area);
             }
@@ -673,6 +587,8 @@ void UiController::hideAssistant(const KDevelop::IAssistant::Ptr& assistant)
 void UiController::popUpAssistant(const KDevelop::IAssistant::Ptr& assistant)
 {
     assistantHide();
+    if(!assistant)
+        return;
     
     Sublime::View* view = d->activeSublimeWindow->activeView();
     TextEditorWidget* textWidget = dynamic_cast<TextEditorWidget*>(view->widget());
