@@ -28,6 +28,7 @@
 #include "document.h"
 #include "areaindex.h"
 #include "controller.h"
+#include <qpointer.h>
 
 namespace Sublime {
 
@@ -48,8 +49,10 @@ struct AreaPrivate {
         toolViewPositions.clear();
         desiredToolViews = p.desiredToolViews;
         shownToolView = p.shownToolView;
+        workingSet = p.workingSet;
 
         title = p.title;
+        iconName = p.iconName;
     }
     ~AreaPrivate()
     {
@@ -90,6 +93,7 @@ struct AreaPrivate {
     QMap<Sublime::Position, QString> shownToolView;
     QMap<Sublime::Position, int> thickness;
     QString iconName;
+    QString workingSet;
 };
 
 
@@ -105,6 +109,8 @@ Area::Area(Controller *controller, const QString &name, const QString &title)
     d->title = title;
     d->controller = controller;
     d->iconName = "kdevelop";
+    d->workingSet = QString();
+    kDebug() << "initial working-set:" << d->workingSet;
     initialize();
 }
 
@@ -148,6 +154,7 @@ void Sublime::Area::addView(View *view, AreaIndex *index)
 {
     index->add(view);
     connect(view, SIGNAL(positionChanged(Sublime::View*, int)), this, SLOT(positionChanged(Sublime::View*, int)));
+    kDebug() << "view added in" << this;
     emit viewAdded(index, view);
     connect(this, SIGNAL(destroyed()), view, SLOT(deleteLater()));
 }
@@ -168,6 +175,7 @@ void Area::addView(View *view, View *viewToSplit, Qt::Orientation orientation)
 {
     AreaIndex *indexToSplit = indexOf(viewToSplit);
     indexToSplit->split(view, orientation);
+    kDebug() << "view added in" << this;
     emit viewAdded(indexToSplit, view);
     connect(this, SIGNAL(destroyed()), view, SLOT(deleteLater()));
 }
@@ -179,6 +187,8 @@ View* Area::removeView(View *view)
 
     emit aboutToRemoveView(index, view);
     index->remove(view);
+    emit viewRemoved(index, view);
+    
     return view;
 }
 
@@ -286,6 +296,7 @@ void Area::save(KConfigGroup& group) const
     group.writeEntry("thickness right", thickness(Sublime::Right));
     group.writeEntry("thickness bottom", thickness(Sublime::Bottom));
     group.writeEntry("thickness top", thickness(Sublime::Top));
+    group.writeEntry("working set", d->workingSet);
 }
 
 void Area::load(const KConfigGroup& group)
@@ -317,6 +328,7 @@ void Area::load(const KConfigGroup& group)
     setThickness(Sublime::Right, group.readEntry("thickness right", -1));
     setThickness(Sublime::Bottom, group.readEntry("thickness bottom", -1));
     setThickness(Sublime::Top, group.readEntry("thickness top", -1));
+    setWorkingSet(group.readEntry("working set", d->workingSet));
 }
 
 bool Area::wantToolView(const QString& id)
@@ -369,6 +381,51 @@ void Area::positionChanged(View *view, int newPos)
     index->views().move(index->views().indexOf(view), newPos);
 }
 
+
+QString Area::workingSet() const
+{
+    return d->workingSet;
+}
+
+
+void Area::setWorkingSet(QString name)
+{
+    if(name != d->workingSet) {
+        kDebug() << this << "setting new working-set" << name;
+        QString oldName = d->workingSet;
+        emit changingWorkingSet(this, oldName, name);
+        d->workingSet = name;
+        emit changedWorkingSet(this, oldName, name);
+    }
+}
+
+bool Area::closeView(View* view)
+{
+    QPointer<Document> doc = view->document();
+
+    if(doc && doc->views().count() == 1) {
+        if(!doc->closeDocument())
+            return false;
+        else
+            return true;
+    }
+    
+    //close only one active view
+    removeView(view);
+    delete view;
+
+    if(doc && doc->views().count() == 0)
+        doc->closeDocument(); //close the document instead
+
+    return true;
+}
+
+void Area::clearViews()
+{
+    foreach(Sublime::View* view, views())
+        closeView(view);
+}
+
 }
 
 #include "area.moc"
