@@ -83,13 +83,25 @@ public:
     /**Adds the @p view to the area splitting the @p viewToSplit using
     given @p orientation.*/
     void addView(View *view, View *viewToSplit, Qt::Orientation orientation);
-    /**Removes the @p view from the area.*/
+    /**Removes the @p view from the area. Does not delete it. */
     View* removeView(View *view);
     /**@return the list of all views in this area in no particular order. To
     process the views in ordered manner (tree walk) use @ref walkViews method.
     This method is added only for convenience.*/
     QList<View*> views();
 
+    /** Removes all views from this area and deletes them.
+      * If an open document has changes, and it is the last view of that document,
+      * the user may push 'Cancel', and the view will stay active. */
+    void clearViews();
+    
+    /** Closes and deletes the view, asking the user for feedback if needed.
+      * Closes the document if it is the last view.
+      * Does allow breaking the closing process.
+      * If it is the last view of the document that has changes, and the user pushed 'Cancel',
+      * false will be returned, and the view will not be closed. */
+    bool closeView(View* view);
+    
     /**@return the index of view or 0 if it can not be found.*/
     AreaIndex *indexOf(View *view);
     /**@return the root index of the area. Root index always exists so this
@@ -133,6 +145,15 @@ public:
     /**@return the controller for this area.*/
     Controller *controller() const;
 
+    ///Returns the currently set working-set for this area. The working-set is persistent
+    QString workingSet() const;
+    ///Sets the working-set for this area. The working-set is just a marker, and does nothing
+    ///within Area.
+    ///The actual view management has to be implemented in the entity that knows more
+    ///about possible views, documents, etc. (kdevplatform/shell)
+    ///@warning (KDevelop): Before calling this, make sure that all views are saved!
+    void setWorkingSet(QString name);
+    
     /**Walker mode to determine the behavior of area walkers.*/
     enum WalkerMode {
         StopWalker,       /**< Stop after processing this area index or toolview */
@@ -182,12 +203,14 @@ public:
     */
     template <typename Operator>
     void walkToolViews(Operator &op, Positions positions);
-
+    
 Q_SIGNALS:
     /**Emitted when a new view is added to the area.*/
     void viewAdded(Sublime::AreaIndex*, Sublime::View*);
     /**Emitted when a view is going to be removed from the area.*/
     void aboutToRemoveView(Sublime::AreaIndex*, Sublime::View*);
+    /**Emitted when a view was removed from the area.*/
+    void viewRemoved(Sublime::AreaIndex*, Sublime::View*);
     /**Emitted when a new toolview is added to the area.*/
     void toolViewAdded(Sublime::View*, Sublime::Position);
     /**Emitted when a toolview is requesting to be raised.*/
@@ -196,6 +219,10 @@ Q_SIGNALS:
     void aboutToRemoveToolView(Sublime::View*, Sublime::Position);
     /**Emitted when a toolview is moved to a different position.*/
     void toolViewMoved(Sublime::View*, Sublime::Position);
+    /**Emitted before the working-set is changed.*/
+    void changingWorkingSet(Sublime::Area* area, QString from, QString to);
+    /**Emitted after the working-set was changed.*/
+    void changedWorkingSet(Sublime::Area* area, QString from, QString to);
 
 private Q_SLOTS:
     void positionChanged(Sublime::View*, int);
