@@ -38,6 +38,7 @@
 
 #include "view.h"
 #include "document.h"
+#include <qpointer.h>
 
 namespace Sublime {
 
@@ -50,6 +51,7 @@ struct ContainerPrivate {
     QStackedWidget *stack;
     QLabel *fileNameCorner;
     QLabel *statusCorner;
+    QPointer<QWidget> leftCornerWidget;
 
     bool openAfterCurrent;
 };
@@ -72,14 +74,22 @@ protected:
             QStyleOptionTabBarBase optTabBase;
             optTabBase.init(m_tabBar);
             optTabBase.shape = m_tabBar->shape();
+            optTabBase.tabBarRect = m_tabBar->rect();
+            optTabBase.tabBarRect.moveRight(0);
 
             QStyleOptionTab tabOverlap;
             tabOverlap.shape = m_tabBar->shape();
             int overlap = style()->pixelMetric(QStyle::PM_TabBarBaseOverlap, &tabOverlap, m_tabBar);
-            QRect rect;
-            rect.setRect(0, height()-overlap, width(), overlap);
-            optTabBase.rect = rect;
-            p.drawPrimitive(QStyle::PE_FrameTabBarBase, optTabBase);
+            if( overlap > 0 ) 
+            {
+                QRect rect;
+                rect.setRect(0, height()-overlap, width(), overlap);
+                optTabBase.rect = rect;
+            }
+            if( m_tabBar->drawBase() )
+            {
+                p.drawPrimitive(QStyle::PE_FrameTabBarBase, optTabBase);
+            }
         }
     }
 
@@ -119,17 +129,17 @@ Container::Container(QWidget *parent)
     l->setMargin(0);
     l->setSpacing(0);
 
-    QBoxLayout *h = new QBoxLayout(QBoxLayout::LeftToRight);
-    h->setMargin(0);
-    h->setSpacing(0);
+    m_tabBarLayout = new QBoxLayout(QBoxLayout::LeftToRight);
+    m_tabBarLayout->setMargin(0);
+    m_tabBarLayout->setSpacing(0);
 
     d->tabBar = new KTabBar(this);
-    h->addWidget(d->tabBar);
+    m_tabBarLayout->addWidget(d->tabBar);
     d->fileNameCorner = new UnderlinedLabel(d->tabBar, this);
-    h->addWidget(d->fileNameCorner);
+    m_tabBarLayout->addWidget(d->fileNameCorner);
     d->statusCorner = new StatusLabel(d->tabBar, this);
-    h->addWidget(d->statusCorner);
-    l->addLayout(h);
+    m_tabBarLayout->addWidget(d->statusCorner);
+    l->addLayout(m_tabBarLayout);
 
     d->stack = new QStackedWidget(this);
     l->addWidget(d->stack);
@@ -154,6 +164,21 @@ Container::Container(QWidget *parent)
     setOpenAfterCurrent(group.readEntry("TabBarOpenAfterCurrent", 1) == 1);
 }
 
+void Container::setLeftCornerWidget(QWidget* widget)
+{
+    if(d->leftCornerWidget == widget) {
+        if(d->leftCornerWidget)
+            d->leftCornerWidget->setParent(0);
+    }else{
+        delete d->leftCornerWidget;
+    }
+    d->leftCornerWidget = widget;
+    if(!widget)
+        return;
+    widget->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
+    m_tabBarLayout->insertWidget(0, widget);
+}
+
 Container::~Container()
 {
     delete d;
@@ -211,9 +236,10 @@ void Container::addWidget(View *view)
     }
     else
         d->stack->addWidget(w);
-    d->tabBar->insertTab(idx, view->document()->title());
+    d->tabBar->insertTab(idx, view->document()->statusIcon(), view->document()->title());
     d->viewForWidget[w] = view;
     connect(view, SIGNAL(statusChanged(Sublime::View*)), this, SLOT(statusChanged(Sublime::View*)));
+    connect(view->document(), SIGNAL(statusIconChanged(Sublime::Document*)), this, SLOT(statusIconChanged(Sublime::Document*)));
     connect(view->document(), SIGNAL(titleChanged(Sublime::Document*)), this, SLOT(documentTitleChanged(Sublime::Document*)));
 }
 
@@ -222,6 +248,21 @@ void Container::statusChanged(Sublime::View* view)
     d->statusCorner->setText(view->viewStatus());
 }
 
+
+void Container::statusIconChanged(Document* doc)
+{
+    QMapIterator<QWidget*, View*> it = d->viewForWidget;
+    while (it.hasNext()) {
+        if (it.next().value()->document() == doc) {
+            int tabIndex = d->stack->indexOf(it.key());
+            if (tabIndex != -1) {
+                d->tabBar->setTabIcon(tabIndex, doc->statusIcon());
+            }
+            break;
+        }
+    }
+}
+
 void Container::documentTitleChanged(Sublime::Document* doc)
 {
     QMapIterator<QWidget*, View*> it = d->viewForWidget;
@@ -278,6 +319,7 @@ void Sublime::Container::removeWidget(QWidget *w)
         if (view)
         {
             disconnect(view->document(), SIGNAL(titleChanged(Sublime::Document*)), this, SLOT(documentTitleChanged(Sublime::Document*)));
+            disconnect(view->document(), SIGNAL(statusIconChanged(Sublime::Document*)), this, SLOT(statusIconChanged(Sublime::Document*)));
             disconnect(view, SIGNAL(statusChanged(Sublime::View*)), this, SLOT(statusChanged(Sublime::View*)));
         }
     }
@@ -293,11 +335,6 @@ View *Container::viewForWidget(QWidget *w) const
     return d->viewForWidget[w];
 }
 
-void Container::setTabIcon(int index, const QIcon& icon) const
-{
-    d->tabBar->setTabIcon(index, icon);
-}
-
 void Container::setTabBarHidden(bool hide)
 {
     if (hide)
