@@ -23,6 +23,8 @@
 
 #include "sublimeexport.h"
 
+class QBoxLayout;
+
 class QPaintEvent;
 
 namespace Sublime {
@@ -54,13 +56,16 @@ public:
     void setCurrentWidget(QWidget *w);
     QWidget *widget(int i) const;
     int indexOf(QWidget *w) const;
-    void setTabIcon(int index, const QIcon &icon) const;
 
     View *viewForWidget(QWidget *w) const;
 
     void setTabBarHidden(bool hide);
     void setOpenAfterCurrent(bool after);
 
+    /** Adds a corner widget to the left of this containers tab-bar. To remove it again, just delete it.
+      * The ownership otherwise goes to the container. */
+    void setLeftCornerWidget(QWidget* widget);
+
 Q_SIGNALS:
     void activateView(Sublime::View* view);
     void closeRequest(QWidget *w);
@@ -68,6 +73,7 @@ Q_SIGNALS:
 private Q_SLOTS:
     void widgetActivated(int idx);
     void documentTitleChanged(Sublime::Document* doc);
+    void statusIconChanged(Sublime::Document*);
     void statusChanged(Sublime::View *view);
     void closeRequest(int idx);
     void tabMoved(int from, int to);
@@ -76,6 +82,7 @@ private:
 
     struct ContainerPrivate * const d;
 
+    QBoxLayout* m_tabBarLayout;
 };
 
 }
