@@ -139,21 +139,7 @@ void Controller::showAreaInternal(Area* area, MainWindow *mainWindow)
        main window if an area not visible now is modified.  Further,
        if showAreaInternal is called with the same area as is current
        now, we don't want to connect the same signals twice.  */
-    if (mainWindow->area())
-        disconnect(mainWindow->area(), 0, mainWindow, 0);
     MainWindowOperator::setArea(mainWindow, area);
-    connect(area, SIGNAL(viewAdded(Sublime::AreaIndex*, Sublime::View*)),
-        mainWindow, SLOT(viewAdded(Sublime::AreaIndex*, Sublime::View*)));
-    connect(area, SIGNAL(requestToolViewRaise(Sublime::View*)),
-        mainWindow, SLOT(raiseToolView(Sublime::View*)));
-    connect(area, SIGNAL(aboutToRemoveView(Sublime::AreaIndex*, Sublime::View*)),
-        mainWindow, SLOT(aboutToRemoveView(Sublime::AreaIndex*, Sublime::View*)));
-    connect(area, SIGNAL(toolViewAdded(Sublime::View*, Sublime::Position)),
-        mainWindow, SLOT(toolViewAdded(Sublime::View*, Sublime::Position)));
-    connect(area, SIGNAL(aboutToRemoveToolView(Sublime::View*, Sublime::Position)),
-        mainWindow, SLOT(aboutToRemoveToolView(Sublime::View*, Sublime::Position)));
-    connect(area, SIGNAL(toolViewMoved(Sublime::View*, Sublime::Position)),
-        mainWindow, SLOT(toolViewMoved(Sublime::View*, Sublime::Position)));
 }
 
 void Controller::showArea(const QString& areaTypeId, MainWindow *mainWindow)
@@ -207,6 +193,14 @@ const QList<Area*> &Controller::defaultAreas() const
     return d->areas;
 }
 
+
+const QList< Area* >& Controller::areas(MainWindow* mainWindow) const
+{
+    int index = d->controlledWindows.indexOf(mainWindow);
+    Q_ASSERT(index != -1);
+    return areas(index);
+}
+
 const QList<Area*> &Controller::areas(int mainWindow) const
 {
     return d->mainWindowAreas[mainWindow];
@@ -227,6 +221,7 @@ void Controller::addDefaultArea(Area *area)
     d->areas.append(area);
     d->allAreas.append(area);
     d->namedAreas[area->objectName()] = area;
+    emit areaCreated(area);
 }
 
 void Controller::addMainWindow(MainWindow* mainWindow)
@@ -241,6 +236,7 @@ void Controller::addMainWindow(MainWindow* mainWindow)
         Area *na = new Area(*area);
         d->allAreas.append(na);
         d->mainWindowAreas[index].push_back(na);
+        emit areaCreated(na);
     }
     showAreaInternal(d->mainWindowAreas[index][0], mainWindow);
     emit mainWindowAdded( mainWindow );
@@ -254,18 +250,19 @@ void Controller::addDocument(Document *document)
 void Controller::areaReleased()
 {
     MainWindow *w = reinterpret_cast<Sublime::MainWindow*>(sender());
-    kDebug() << "marking areas as mainwindow-free";
+    kDebug() << "marking areas as mainwindow-free" << w << d->controlledWindows.contains(w) << d->shownAreas.keys(w);
     foreach (Area *area, d->shownAreas.keys(w))
     {
         kDebug() << "" << area->objectName();
         areaReleased(area);
         disconnect(area, 0, w, 0);
     }
+
+    d->controlledWindows.removeAll(w);
 }
 
 void Controller::areaReleased(Sublime::Area *area)
 {
-    d->controlledWindows.removeAll(d->shownAreas[area]);
     d->shownAreas.remove(area);
     d->namedAreas.remove(area->objectName());
 }
@@ -383,11 +380,7 @@ void Controller::notifyViewAdded(Sublime::AreaIndex*, Sublime::View *view)
 
 void Controller::setStatusIcon(Document * document, const QIcon & icon)
 {
-    foreach (MainWindow* mw, mainWindows())
-        if (mw->area())
-            foreach (View* view, mw->area()->views())
-                if (view->document() == document)
-                    MainWindowOperator::setStatusIcon(mw, view, icon);
+    document->setStatusIcon(icon);
 }
 
 }
