@@ -36,6 +36,8 @@
 #include "view.h"
 #include "document.h"
 #include "mainwindow.h"
+#include <QVBoxLayout>
+#include <QLabel>
 
 using namespace Sublime;
 
@@ -114,11 +116,30 @@ IdealButtonBarWidget::IdealButtonBarWidget(Qt::DockWidgetArea area, IdealMainWid
     : QWidget(parent)
     , _area(area)
     , _actions(new QActionGroup(this))
+    , _corner(0)
 {
     // TODO Only for now...
     _actions->setExclusive(true);
 
-    (void) new IdealButtonBarLayout(orientation(), this);
+    if (area == Qt::BottomDockWidgetArea)
+    {
+        QBoxLayout *statusLayout = new QBoxLayout(QBoxLayout::RightToLeft, this);
+        statusLayout->setMargin(0);
+        statusLayout->setSpacing(IDEAL_LAYOUT_SPACING);
+        statusLayout->setContentsMargins(0, IDEAL_LAYOUT_MARGIN, 0, IDEAL_LAYOUT_MARGIN);
+
+        IdealButtonBarLayout *l = new IdealButtonBarLayout(orientation());
+        statusLayout->addLayout(l);
+
+        _corner = new QWidget(this);
+        QBoxLayout *cornerLayout = new QBoxLayout(QBoxLayout::LeftToRight, _corner);
+        cornerLayout->setMargin(0);
+        cornerLayout->setSpacing(0);
+        statusLayout->addWidget(_corner);
+        statusLayout->addStretch(1);
+    }
+    else
+        (void) new IdealButtonBarLayout(orientation(), this);
 }
 
 KAction *IdealButtonBarWidget::addWidget(const QString& title, IdealDockWidget *dock,
@@ -149,6 +170,11 @@ KAction *IdealButtonBarWidget::addWidget(const QString& title, IdealDockWidget *
     return action;
 }
 
+QWidget* IdealButtonBarWidget::corner()
+{
+    return _corner;
+}
+
 void IdealButtonBarWidget::removeAction(QAction * action)
 {
     _widgets.remove(action);
@@ -276,14 +302,14 @@ IdealDockWidget::IdealDockWidget(QWidget *parent)
 	m_anchor->setWhatsThis(i18n("<b>Lock the tool</b><p>When a tool is unlocked, it "
 				    "will be automatically hidden when you click outside it. "
 				    "A locked tool will remain visible until you explicitly "
-				    "hide it, or switch to a different tool."));
+				    "hide it, or switch to a different tool.</p>"));
 	connect(m_anchor, SIGNAL(toggled(bool)), SIGNAL(anchor(bool)));
 
 	m_close = closeButton;
 	m_close->setToolTip(i18n("Remove the tool"));
 	m_close->setWhatsThis(i18n("<b>Remove the tool</b><p>Removes this tool completely. "
 				   "You can add the tool again by using the "
-				   "<tt>View->Add Tool View</tt> command."));
+				   "<tt>View->Add Tool View</tt> command.</p>"));
 	connect(m_close, SIGNAL(clicked(bool)), this, SLOT(slotRemove()));
     }
 }
@@ -425,7 +451,7 @@ IdealMainWidget::IdealMainWidget(MainWindow* parent, KActionCollection* ac)
     rightBarWidget->hide();
 
     bottomBarWidget = new IdealButtonBarWidget(Qt::BottomDockWidgetArea, this);
-    bottomBarWidget->hide();
+    bottomStatusBarLocation = bottomBarWidget->corner();
 
     topBarWidget = new IdealButtonBarWidget(Qt::TopDockWidgetArea, this);
     topBarWidget->hide();
@@ -440,69 +466,17 @@ IdealMainWidget::IdealMainWidget(MainWindow* parent, KActionCollection* ac)
 
     connect(parent, SIGNAL(settingsLoaded()), m_mainLayout, SLOT(loadSettings()));
 
-    KAction* action = m_showLeftDock = new KAction(i18n("Show Left Dock"), this);
-    action->setCheckable(true);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_L);
-    connect(action, SIGNAL(toggled(bool)), SLOT(showLeftDock(bool)));
-    ac->addAction("show_left_dock", action);
+    Q_ASSERT(parent->action("docks_submenu"));
+    Q_ASSERT(qobject_cast<KActionMenu*>(parent->action("docks_submenu")));
 
-    m_showRightDock = action = new KAction(i18n("Show Right Dock"), this);
-    action->setCheckable(true);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_R);
-    connect(action, SIGNAL(toggled(bool)), SLOT(showRightDock(bool)));
-    ac->addAction("show_right_dock", action);
+    m_showLeftDock = qobject_cast<KAction*>(parent->action("show_left_dock"));
+    m_showRightDock = qobject_cast<KAction*>(parent->action("show_right_dock"));
+    m_showBottomDock = qobject_cast<KAction*>(parent->action("show_bottom_dock"));
+    m_showTopDock = qobject_cast<KAction*>(parent->action("show_top_dock"));
 
-    m_showBottomDock = action = new KAction(i18n("Show Bottom Dock"), this);
-    action->setCheckable(true);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_B);
-    connect(action, SIGNAL(toggled(bool)), SLOT(showBottomDock(bool)));
-    ac->addAction("show_bottom_dock", action);
-
-    m_showTopDock = action = new KAction(i18n("Show Top Dock"), this);
-    action->setCheckable(true);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_T);
-    connect(action, SIGNAL(toggled(bool)), SLOT(showTopDock(bool)));
-    ac->addAction("show_top_dock", action);
-
-    action = new KAction(i18n("Hide/Restore Docks"), this);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_H);
-    connect(action, SIGNAL(triggered(bool)), SLOT(toggleDocksShown()));
-    ac->addAction("hide_all_docks", action);
-
-    action = new KAction(i18n("Focus Editor"), this);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_E);
-    connect(action, SIGNAL(triggered(bool)), SLOT(focusEditor()));
-    ac->addAction("focus_editor", action);
-
-    m_anchorCurrentDock = action = new KAction(i18n("Anchor Current Dock"), this);
-    action->setCheckable(true);
-    action->setEnabled(false);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_A);
-    connect(action, SIGNAL(toggled(bool)), SLOT(anchorCurrentDock(bool)));
-    ac->addAction("anchor_current_dock", action);
-
-    m_maximizeCurrentDock = action = new KAction(i18n("Maximize Current Dock"), this);
-    action->setCheckable(true);
-    action->setEnabled(false);
-    connect(action, SIGNAL(toggled(bool)), SLOT(maximizeCurrentDock(bool)));
-    ac->addAction("maximize_current_dock", action);
-
-    action = new KAction(i18n("Select Next Dock"), this);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_N);
-    connect(action, SIGNAL(triggered(bool)), SLOT(selectNextDock()));
-    ac->addAction("select_next_dock", action);
-
-    action = new KAction(i18n("Select Previous Dock"), this);
-    action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_P);
-    connect(action, SIGNAL(triggered(bool)), SLOT(selectPreviousDock()));
-    ac->addAction("select_previous_dock", action);
-
-    action = new KAction(i18n("Remove view"), this);
-    connect(action, SIGNAL(triggered(bool)), SLOT(removeView()));
-    ac->addAction("remove_view", action);
-
-    action = m_docks = new KActionMenu(i18n("Docks"), this);
-    ac->addAction("docks_submenu", action);
+    m_anchorCurrentDock = qobject_cast<KAction*>(parent->action("anchor_current_dock"));
+    m_maximizeCurrentDock = qobject_cast<KAction*>(parent->action("maximize_current_dock"));
+    m_docks = qobject_cast<KActionMenu*>(parent->action("docks_submenu"));
 }
 
 void IdealMainWidget::addView(Qt::DockWidgetArea area, View* view)
@@ -1041,6 +1015,11 @@ void Sublime::IdealMainWidget::focusEditor()
             view->widget()->setFocus(Qt::ShortcutFocusReason);
 }
 
+QWidget *IdealMainWidget::statusBarLocation() const
+{
+    return bottomStatusBarLocation;
+}
+
 IdealDockWidgetButton::IdealDockWidgetButton(QWidget *parent)
     : QToolButton(parent)
 {
