@@ -44,9 +44,44 @@ MainWindow::MainWindow(Controller *controller, Qt::WindowFlags flags)
 : KParts::MainWindow(0, flags), d(new MainWindowPrivate(this, controller))
 {
     connect(this, SIGNAL(destroyed()), controller, SLOT(areaReleased()));
-    connect(this, SIGNAL(areaCleared(Sublime::Area*)), controller, SLOT(areaReleased(Sublime::Area*)));
 
     loadGeometry(KGlobal::config()->group("Main Window"));
+#if QT_VERSION >= 0x040500   
+    d->areaSwitcher = new AreaTabWidget(menuBar());
+    menuBar()->setCornerWidget(d->areaSwitcher, Qt::TopRightCorner);
+#endif
+}
+
+QWidget* MainWindow::customButtonForAreaSwitcher ( Area* /*area*/ )
+{
+    return 0;
+}
+
+void MainWindow::setupAreaSelector() {
+#if QT_VERSION >= 0x040500
+    disconnect(d->areaSwitcher->tabBar, SIGNAL(currentChanged(int)), d, SLOT(toggleArea(int)));
+    
+    d->areaSwitcher->tabBar->clearTabs();
+    
+    int currentIndex = -1;
+    
+    QList< Area* > areas = controller()->areas(this);
+    if(areas.isEmpty())
+        areas = controller()->defaultAreas();
+    
+    for(int a = 0; a < areas.size(); ++a) {
+        Area* theArea = areas[a];
+        
+        if(theArea->objectName() == area()->objectName()) {
+            currentIndex = a;
+        }
+        
+        d->areaSwitcher->tabBar->addCustomTab(theArea->title(), KIcon(theArea->iconName()), currentIndex == a, theArea->objectName(), customButtonForAreaSwitcher(theArea));
+    }
+    
+    d->areaSwitcher->tabBar->setCurrentIndex(currentIndex);
+    connect(d->areaSwitcher->tabBar, SIGNAL(currentChanged(int)), d, SLOT(toggleArea(int)));
+#endif
 }
 
 MainWindow::~MainWindow()
@@ -57,6 +92,9 @@ MainWindow::~MainWindow()
 
 void MainWindow::setArea(Area *area)
 {
+    if (d->area)
+        disconnect(d->area, 0, this, 0);
+    
     bool differentArea = (area != d->area);
     /* All views will be removed from dock area now.  However, this does
        not mean those are removed from area, so prevent slotDockShown
@@ -68,6 +106,7 @@ void MainWindow::setArea(Area *area)
 
     if (d->area)
         clearArea();
+
     d->area = area;
     d->reconstruct();
     d->activateFirstVisibleView();
@@ -76,6 +115,21 @@ void MainWindow::setArea(Area *area)
     d->ignoreDockShown = false;
     
     loadSettings();
+        
+    connect(area, SIGNAL(viewAdded(Sublime::AreaIndex*, Sublime::View*)),
+        this, SLOT(viewAdded(Sublime::AreaIndex*, Sublime::View*)));
+    connect(area, SIGNAL(requestToolViewRaise(Sublime::View*)),
+        this, SLOT(raiseToolView(Sublime::View*)));
+    connect(area, SIGNAL(aboutToRemoveView(Sublime::AreaIndex*, Sublime::View*)),
+        this, SLOT(aboutToRemoveView(Sublime::AreaIndex*, Sublime::View*)));
+    connect(area, SIGNAL(toolViewAdded(Sublime::View*, Sublime::Position)),
+        this, SLOT(toolViewAdded(Sublime::View*, Sublime::Position)));
+    connect(area, SIGNAL(aboutToRemoveToolView(Sublime::View*, Sublime::Position)),
+        this, SLOT(aboutToRemoveToolView(Sublime::View*, Sublime::Position)));
+    connect(area, SIGNAL(toolViewMoved(Sublime::View*, Sublime::Position)),
+        this, SLOT(toolViewMoved(Sublime::View*, Sublime::Position)));
+     connect(area, SIGNAL(changedWorkingSet(Sublime::Area*,QString,QString)),
+        this, SLOT(setupAreaSelector()));
 }
 
 void MainWindow::initializeStatusBar()
@@ -239,11 +293,6 @@ bool MainWindow::queryClose()
     return KParts::MainWindow::queryClose();
 }
 
-void Sublime::MainWindow::setStatusIcon(View * view, const QIcon & icon)
-{
-    d->setStatusIcon(view, icon);
-}
-
 void MainWindow::saveGeometry(KConfigGroup &config)
 {
     int scnum = QApplication::desktop()->screenNumber(parentWidget());
@@ -289,6 +338,18 @@ QWidget *MainWindow::statusBarLocation()
     return d->idealMainWidget->statusBarLocation();
 }
 
+void MainWindow::setAreaSwitcherCornerWidget(QWidget* widget)
+{
+#if QT_VERSION >= 0x040500
+    d->areaSwitcher->setTabSideWidget(widget);
+#endif
+}
+
+void MainWindow::setTabBarLeftCornerWidget(QWidget* widget)
+{
+    d->setTabBarLeftCornerWidget(widget);
+}
+
 }
 
 #include "mainwindow.moc"
