@@ -121,6 +121,12 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
     recreateCentralWidget();
 }
 
+
+MainWindowPrivate::~MainWindowPrivate()
+{
+    delete m_leftTabbarCornerWidget;
+}
+
 void MainWindowPrivate::showLeftDock(bool b)
 {
     idealMainWidget->showLeftDock(b);
@@ -249,6 +255,9 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
 
 void MainWindowPrivate::reconstruct()
 {
+    if(m_leftTabbarCornerWidget)
+        m_leftTabbarCornerWidget->setParent(0);
+    
     IdealToolViewCreator toolViewCreator(this);
     area->walkToolViews(toolViewCreator, Sublime::AllPositions);
 
@@ -274,10 +283,15 @@ void MainWindowPrivate::reconstruct()
         }
     }
     idealMainWidget->blockSignals(false);
+    
+    setTabBarLeftCornerWidget(m_leftTabbarCornerWidget);
 }
 
 void MainWindowPrivate::clearArea()
 {
+    if(m_leftTabbarCornerWidget)
+        m_leftTabbarCornerWidget->setParent(0);
+    
     //reparent toolview widgets to 0 to prevent their deletion together with dockwidgets
     foreach (View *view, area->toolViews())
     {
@@ -302,6 +316,9 @@ void MainWindowPrivate::clearArea()
     m_mainWindow->setActiveView(0);
     m_indexSplitters.clear();
     area = 0;
+    viewContainers.clear();
+    
+    setTabBarLeftCornerWidget(m_leftTabbarCornerWidget);
 }
 
 void MainWindowPrivate::recreateCentralWidget()
@@ -325,7 +342,6 @@ void MainWindowPrivate::recreateCentralWidget()
             SIGNAL(widgetResized(IdealMainLayout::Role, int)),
             this,
             SLOT(widgetResized(IdealMainLayout::Role, int)));
-
 }
 
 void MainWindowPrivate::
@@ -343,6 +359,9 @@ slotDockShown(Sublime::View* view, Sublime::Position pos, bool shown)
 
 void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view)
 {
+    if(m_leftTabbarCornerWidget)
+        m_leftTabbarCornerWidget->setParent(0);
+    
     ViewCreator viewCreator(this);
     QSplitter *splitter = m_indexSplitters[index];
     if (index->isSplitted() && (splitter->count() == 1) &&
@@ -360,6 +379,8 @@ void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view
     }
     area->walkViews(viewCreator, index);
     emit m_mainWindow->viewAdded( view );
+    
+    setTabBarLeftCornerWidget(m_leftTabbarCornerWidget);
 }
 
 void Sublime::MainWindowPrivate::raiseToolView(Sublime::View * view)
@@ -403,6 +424,9 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
     }
     else
     {
+        if(m_leftTabbarCornerWidget)
+            m_leftTabbarCornerWidget->setParent(0);
+        
         // We've about to remove the last view of this container.  It will
         // be empty, so have to delete it, as well.
 
@@ -416,9 +440,11 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
         else
             kWarning() << "View does not have a widget!";
 
+        Q_ASSERT(container->count() == 0);
         // We can be called from signal handler of container
         // (which is tab widget), so defer deleting it.
         container->deleteLater();
+        container->setParent(0);
 
         /* If we're not at the top level, we get to collapse split views.  */
         if (index->parent())
@@ -465,14 +491,19 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
             kDebug() << "after deleation " << parent << " has "
                          << parentSplitter->count() << " elements";
 
+            
             //find the container somewhere to activate
             Container *containerToActivate = parentSplitter->findChild<Sublime::Container*>();
             //activate the current view there
-            if (containerToActivate)
-                return m_mainWindow->setActiveView(containerToActivate->viewForWidget(containerToActivate->currentWidget()));
+            if (containerToActivate) {
+                m_mainWindow->setActiveView(containerToActivate->viewForWidget(containerToActivate->currentWidget()));
+                setTabBarLeftCornerWidget(m_leftTabbarCornerWidget);
+                return;
+            }
         }
     }
 
+    setTabBarLeftCornerWidget(m_leftTabbarCornerWidget);
     m_mainWindow->setActiveView(0L);
 }
 
@@ -539,17 +570,6 @@ bool MainWindowPrivate::eventFilter(QObject *, QEvent *event)
     return false;
 }
 
-void Sublime::MainWindowPrivate::setStatusIcon(View * view, const QIcon & icon)
-{
-    if (viewContainers.contains(view)) {
-        Container* c = viewContainers[view];
-        int index = c->indexOf(view->widget());
-        if (index != -1) {
-            c->setTabIcon(index, icon);
-        }
-    }
-}
-
 void MainWindowPrivate::widgetResized(IdealMainLayout::Role role, int thickness)
 {
     area->setThickness(IdealMainLayout::positionForRole(role), thickness);
@@ -560,21 +580,204 @@ void MainWindowPrivate::widgetCloseRequest(QWidget* widget)
     if (widgetToView.contains(widget))
     {
         View *view = widgetToView[widget];
-        
-        if (view->document()->views().count() > 1)
-        {
-            //close only one active view
-            area->removeView(view);
-            delete view;
-        }
-        else
-        {
-            //close the document instead
-            view->document()->closeDocument();
-        }
+        area->closeView(view);
     }
 }
 
+void MainWindowPrivate::toggleArea ( int index ) {
+#if QT_VERSION >= 0x040500
+    m_mainWindow->controller()->showArea(areaSwitcher->tabBar->areaId(index), m_mainWindow);
+#endif
+}
+
+#if QT_VERSION >= 0x040500
+void AreaTabBar::paintEvent ( QPaintEvent* ev ) {
+    QTabBar::paintEvent(ev);
+    if ( currentIndex() != -1 ) {
+        QStylePainter p ( this );
+        //Draw highlight behind current area
+        QRect activeRect = tabRect ( currentIndex() );
+        QRect tabArea = activeRect;
+        QImage img ( tabArea.width(), tabArea.height(), QImage::Format_ARGB32 );
+        img.fill ( 0 );
+        QPainter paintImg ( &img );
+        QColor color ( palette().color ( QPalette::Active, QPalette::Highlight ) );
+        color.setAlpha ( 70 );
+        QRect paint = tabArea;
+        const int margin = 8;
+        paint.setLeft ( margin );
+        paint.setTop ( margin );
+        paint.setRight ( activeRect.width()-margin );
+        paint.setBottom ( activeRect.height()-margin );
+
+        paintImg.fillRect ( paint, color );
+        expblur<16,7> ( img, margin/2 );
+        p.drawImage ( tabArea, img );
+    }
+}
+
+void AreaTabWidget::paintEvent ( QPaintEvent* ev ) {
+    QWidget::paintEvent ( ev );
+
+    if ( tabBar->isVisible() && tabBar->count() > 0 ) {
+        QStylePainter p ( this );
+
+        QStyleOptionTabBarBase optTabBase;
+        optTabBase.init ( tabBar );
+        optTabBase.shape = tabBar->shape();
+        optTabBase.tabBarRect = tabBar->rect();
+        optTabBase.tabBarRect.moveTopLeft(tabBar->pos());
+
+        int sideWidth = width()-tabBar->width();
+
+        QStyleOptionTab tabOverlap;
+        tabOverlap.shape = tabBar->shape();
+        int overlap = style()->pixelMetric ( QStyle::PM_TabBarBaseOverlap, &tabOverlap, tabBar );
+        QRect rect;
+        rect.setRect ( 0, height()-overlap, sideWidth, overlap );
+        optTabBase.rect = rect;
+
+        QImage img ( sideWidth, height(), QImage::Format_ARGB32 );
+        img.fill ( 0 );
+        QStylePainter p2 ( &img, tabBar );
+        p2.drawPrimitive ( QStyle::PE_FrameTabBarBase, optTabBase );
+
+        {
+            //Blend the painted line out to the left
+            QLinearGradient blendOut ( 0, 0, sideWidth, 0 );
+            blendOut.setColorAt ( 0, QColor ( 255, 255, 255, 255 ) );
+            blendOut.setColorAt ( 1, QColor ( 0, 0, 0, 0 ) );
+            QBrush blendBrush ( blendOut );
+
+            p2.setCompositionMode ( QPainter::CompositionMode_DestinationOut );
+            p2.fillRect ( img.rect(), blendBrush );
+        }
+
+        p.setCompositionMode ( QPainter::CompositionMode_SourceOver );
+        p.drawImage ( img.rect(), img );
+    }
+}
+
+QSize AreaTabWidget::sizeHint() const {
+    //Resize to hold the whole length up to the menu
+    static bool zeroSizeHint = false;
+    if ( zeroSizeHint )
+        return QSize();
+    zeroSizeHint = true;
+    int available = bar()->parentWidget()->width() - bar()->sizeHint().width() - 10;
+    zeroSizeHint = false;
+    QSize orig = tabBar->sizeHint();
+    int addFade = available - orig.width();
+    
+    int perfectFade = 500;
+    if(areaSideWidget)
+        perfectFade += areaSideWidget->sizeHint().width();
+    
+    if(addFade > perfectFade)
+        addFade = perfectFade;
+    
+    int wantWidth = addFade + orig.width();
+    
+    if ( wantWidth > orig.width() )
+        orig.setWidth ( wantWidth );
+    return orig;
+}
+
+AreaTabWidget::AreaTabWidget ( QMenuBar* parent ) : QWidget ( parent ), areaSideWidget(0) {
+    m_layout = new QHBoxLayout ( this );
+    m_layout->setAlignment ( Qt::AlignRight );
+    tabBar = new AreaTabBar ( this );
+    m_layout->addWidget ( tabBar );
+    m_layout->setContentsMargins ( 0,0,0,0 );
+    m_leftLayout = new QVBoxLayout;
+    
+    m_leftLayout->setContentsMargins(11, 4, 11, 8); ///@todo These margins are a bit too hardcoded, should depend on style
+    m_layout->insertLayout(0, m_leftLayout);
+}
+
+QSize AreaTabBar::tabSizeHint ( int index ) const {
+    //Since we move all contents into the button, we give approximately the button size as size-hint
+    //QTabBar seems to add useless space for the non-existing tab text
+    QSize ret = QTabBar::tabSizeHint(index);
+    
+    if(ret.width() > buttons[index]->sizeHint().width()+16)
+        ret.setWidth(buttons[index]->sizeHint().width() + 16); ///@todo Where does the offset come from?
+    return ret;
+}
+
+
+void AreaTabButton::setIsCurrent ( bool arg1 ) {
+    m_isCurrent = arg1;
+}
+
+void AreaTabBar::setCurrentIndex ( int index ) {
+    m_currentIndex = index;
+    foreach(AreaTabButton* button, buttons) {
+        button->setIsCurrent(buttons.indexOf(button) == index);
+    }
+    QTabBar::setCurrentIndex ( index );
+    foreach(AreaTabButton* button, buttons) {
+        button->update();
+    }
+    update();
+}
+
+AreaTabBar::AreaTabBar ( QWidget* parent ) : QTabBar ( parent ), m_currentIndex ( -1 ) {
+    setShape ( QTabBar::RoundedNorth );
+    setDocumentMode ( true );
+    setExpanding ( false );
+    setLayoutDirection ( Qt::RightToLeft );
+    setDrawBase ( false );
+    QPalette pal = palette();
+}
+
+AreaTabButton::AreaTabButton ( QString text, QIcon icon, uint iconSize, QWidget* parent, bool isCurrent, QWidget* _customButtonWidget ) : QWidget ( parent ), m_isCurrent ( isCurrent ), customButtonWidget(_customButtonWidget) {
+    QHBoxLayout* layout = new QHBoxLayout ( this );
+    iconLabel = new QLabel ( this );
+    iconLabel->setPixmap ( icon.pixmap ( QSize ( iconSize, iconSize ) ) );
+    iconLabel->setAutoFillBackground ( false );
+    textLabel = new QLabel ( this );
+    textLabel->setText ( text );
+    textLabel->setAutoFillBackground ( false );
+    if(customButtonWidget) {
+        customButtonWidget->setParent(this);
+        layout->addWidget(customButtonWidget);
+    }
+    layout->addWidget ( textLabel );
+    layout->addWidget ( iconLabel );
+    layout->setMargin ( 0 );
+}
+#endif
+
+void MainWindowPrivate::setTabBarLeftCornerWidget(QWidget* widget)
+{
+    if(widget != m_leftTabbarCornerWidget)
+        delete m_leftTabbarCornerWidget;
+    m_leftTabbarCornerWidget = widget;
+    
+    if(!widget || !area || viewContainers.isEmpty())
+        return;
+    
+    AreaIndex* putToIndex = area->rootIndex();
+    QSplitter* splitter = m_indexSplitters[putToIndex];
+    while(putToIndex->isSplitted()) {
+        putToIndex = putToIndex->first();
+        splitter = m_indexSplitters[putToIndex];
+    }
+    
+//     Q_ASSERT(splitter || putToIndex == area->rootIndex());
+    
+    Container* c = 0;
+    if(splitter) {
+        c = qobject_cast<Container*>(splitter->widget(0));
+    }else{
+        c = viewContainers.values()[0];
+    }
+    Q_ASSERT(c);
+    
+    c->setLeftCornerWidget(widget);
+}
+
 }
 
 #include "mainwindow_p.moc"
