@@ -29,14 +29,13 @@
 #include <KMessageBox>
 #include <KDebug>
 
-#include "../idvcsexecutor.h"
 #include "../dvcsjob.h"
+#include "../dvcsplugin.h"
 
-BranchManager::BranchManager(const QString &_repo, KDevelop::IDVCSexecutor* executor, QWidget *parent)
+BranchManager::BranchManager(const QString &_repo, KDevelop::DistributedVersionControlPlugin* executor, QWidget *parent)
     : KDialog(parent)
+    , d(executor)
 {
-    d = executor;
-
     //we do the same in prepareJob, so actually it isn't required
     QFileInfo repoInfo = QFileInfo(_repo);
     if (repoInfo.isFile())
@@ -89,7 +88,7 @@ void BranchManager::createBranch()
     if (d->branches(repo).contains(newBranch))
     {
         KMessageBox::messageBox(this, KMessageBox::Sorry,
-                                i18n("Branch \"%1\" is already exist.\n"
+                                i18n("Branch \"%1\" already exists.\n"
                                         "Pick another name.",
                                         newBranch));
         connect(branchWidget, SIGNAL(itemChanged ( QListWidgetItem *)),
@@ -98,7 +97,7 @@ void BranchManager::createBranch()
     }
 
     kDebug() << "Creating " << baseBranch << " based on " << newBranch;
-    DVCSjob *branchJob = d->branch(repo, baseBranch, newBranch);
+    KDevelop::VcsJob* branchJob = d->branch(repo, baseBranch, newBranch);
 
     if (branchJob)
     {
@@ -119,7 +118,7 @@ void BranchManager::renameBranch(QListWidgetItem * item)
     if (d->branches(repo).contains(newBranch))
     {
         KMessageBox::messageBox(this, KMessageBox::Sorry,
-                                i18n("Branch \"%1\" is already exist.\n"
+                                i18n("Branch \"%1\" already exists.\n"
                                         "Pick another name.",
                                         newBranch));
         //a hack to prevent another one renameBranch() after resetting item to the old value
@@ -132,13 +131,13 @@ void BranchManager::renameBranch(QListWidgetItem * item)
     }
 
     int ret = KMessageBox::messageBox(this, KMessageBox::WarningYesNo, 
-                                      i18n("You're going to rename the branch!\n"
-                                            "%1->%2\nAre you sure?",baseBranch, newBranch));
+                                      i18n("The branch is going to be renamed from\n"
+                                            "%1 to %2.\nAre you sure?",baseBranch, newBranch));
 
     if (ret == QMessageBox::Cancel)
         return;
 
-    DVCSjob *branchJob = d->branch(repo, newBranch, baseBranch, QStringList("-m"));
+    KDevelop::VcsJob *branchJob = d->branch(repo, newBranch, baseBranch, QStringList("-m"));
     if (branchJob)
     {
         kDebug() << "Renaming " << baseBranch << " to " << newBranch;
@@ -153,20 +152,20 @@ void BranchManager::delBranch()
     if (baseBranch == d->curBranch(repo))
     {
         KMessageBox::messageBox(this, KMessageBox::Sorry,
-                                    i18n("You're on the branch \"%1\"\n"
-                                            "To remove it you have to checkout to another branch!",
+                                    i18n("Currently at the branch \"%1\".\n"
+                                            "To remove it, another branch has to be checked out.",
                                             baseBranch));
         return;
     }
 
     int ret = KMessageBox::messageBox(this, KMessageBox::WarningYesNo, 
-                                      i18n("You're going to remove branch \"%1\"!\n" 
-                                              "You will not be able to restore it!\nAre you sure?",
+                                      i18n("About to remove the branch \"%1\".\n" 
+                                              "Once removed, it cannot be restored.\nAre you sure?",
                                               baseBranch));
     if (ret == QMessageBox::Cancel)
         return;
 
-    DVCSjob *branchJob = d->branch(repo, baseBranch, QString(), QStringList("-D"));
+    KDevelop::VcsJob *branchJob = d->branch(repo, baseBranch, QString(), QStringList("-D"));
     if (branchJob)
     {
         kDebug() << "Removing " << baseBranch;
@@ -186,7 +185,7 @@ void BranchManager::checkoutBranch()
         return;
     }
 
-    DVCSjob *branchJob = d->checkout(repo, baseBranch);
+    KDevelop::VcsJob *branchJob = d->switchBranch(repo, baseBranch);
     if (branchJob)
     {
         //we don't run here, because we have to save all unsaved files (reload proj), checkout and then reload again
