@@ -482,7 +482,7 @@ void VcsBlackBoxTest::testAddRevert(Repo & r)
 
     // Adding sequentially
 
-    for (Repo::StateMap::const_iterator i = r.state.begin(); i != r.state.end(); ++i) {
+    for (Repo::StateMap::const_iterator i = r.state.constBegin(); i != r.state.constEnd(); ++i) {
         r.add(__LINE__, KUrl::List(i->url()), IBasicVersionControl::NonRecursive);
     }
 
@@ -496,7 +496,7 @@ void VcsBlackBoxTest::testAddRevert(Repo & r)
     typedef std::reverse_iterator<Repo::StateMap::const_iterator> StateMapReverseIterator;
 
     // Adding sequentially; this time in reverse order
-    StateMapReverseIterator rbegin(r.state.end()), rend(r.state.begin());
+    StateMapReverseIterator rbegin(r.state.constEnd()), rend(r.state.constBegin());
 
     for (StateMapReverseIterator i = rbegin; i != rend; ++i) {
         r.add(__LINE__, KUrl::List(i->url()), IBasicVersionControl::NonRecursive);
@@ -602,13 +602,13 @@ void VcsBlackBoxTest::testInit()
 {
     for (int i = 0; i < m_primary.size(); ++i) {
         if (m_primary[i]->isDistributed) {
-            DRepo * a = static_cast<DRepo*>(m_primary[i].get());
-            DRepo * b = static_cast<DRepo*>(m_secondary[i].get());
+            DRepo * a = static_cast<DRepo*>(m_primary[i]);
+            DRepo * b = static_cast<DRepo*>(m_secondary[i]);
             repoInit(*a, *b);
         }
         else {
-            CRepo * a = static_cast<CRepo*>(m_primary[i].get());
-            CRepo * b = static_cast<CRepo*>(m_secondary[i].get());
+            CRepo * a = static_cast<CRepo*>(m_primary[i]);
+            CRepo * b = static_cast<CRepo*>(m_secondary[i]);
             repoInit(*a, *b);
         }
     }
@@ -631,8 +631,8 @@ void VcsBlackBoxTest::testCommitModifyRevert()
 void VcsBlackBoxTest::testSharedOps()
 {
     for (int i = 0; i < m_primary.size(); ++i) {
-        Repo * a = m_primary[i].get();
-        Repo * b = m_secondary[i].get();
+        Repo * a = m_primary[i];
+        Repo * b = m_secondary[i];
 
         if (m_primary[i]->isDistributed) {
             testSharedOps(*static_cast<DRepo*>(a), *static_cast<DRepo*>(b));
