@@ -18,9 +18,10 @@
  * 02110-1301, USA.
  */
 
-#include <QMap>
 #include "toolviewdata.h"
 
+#include <QtCore/QMap>
+
 namespace Veritas
 {
 QMap<ITestFramework*, ToolViewData> g_toolViewStore;
